"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import shared.shared_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class Microsoft_DocumentDB(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DATABASE_ACCOUNTS_FIELD_NUMBER: builtins.int
    DATABASE_ACCOUNTS_CASSANDRA_KEYSPACES_FIELD_NUMBER: builtins.int
    DATABASE_ACCOUNTS_CASSANDRA_KEYSPACES_TABLES_FIELD_NUMBER: builtins.int
    DATABASE_ACCOUNTS_GREMLIN_DATABASES_GRAPHS_FIELD_NUMBER: builtins.int
    DATABASE_ACCOUNTS_SQL_DATABASES_FIELD_NUMBER: builtins.int
    DATABASE_ACCOUNTS_SQL_DATABASES_CONTAINERS_FIELD_NUMBER: builtins.int
    DATABASE_ACCOUNTS_SQL_DATABASES_CONTAINERS_STORED_PROCEDURES_FIELD_NUMBER: builtins.int
    @property
    def database_accounts(self) -> global___DatabaseAccounts: ...
    @property
    def database_accounts_cassandra_keyspaces(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___DatabaseAccountsCassandraKeyspaces]: ...
    @property
    def database_accounts_cassandra_keyspaces_tables(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___DatabaseAccountsCassandraKeyspacesTables]: ...
    @property
    def database_accounts_gremlin_databases_graphs(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___DatabaseAccountsGremlinDatabasesGraphs]: ...
    @property
    def database_accounts_sql_databases(self) -> global___DatabaseAccountsSqlDatabases: ...
    @property
    def database_accounts_sql_databases_containers(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___DatabaseAccountsSqlDatabasesContainers]: ...
    @property
    def database_accounts_sql_databases_containers_stored_procedures(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___DatabaseAccountsSqlDatabasesContainersStoredProcedures]: ...
    def __init__(
        self,
        *,
        database_accounts: global___DatabaseAccounts | None = ...,
        database_accounts_cassandra_keyspaces: collections.abc.Iterable[global___DatabaseAccountsCassandraKeyspaces] | None = ...,
        database_accounts_cassandra_keyspaces_tables: collections.abc.Iterable[global___DatabaseAccountsCassandraKeyspacesTables] | None = ...,
        database_accounts_gremlin_databases_graphs: collections.abc.Iterable[global___DatabaseAccountsGremlinDatabasesGraphs] | None = ...,
        database_accounts_sql_databases: global___DatabaseAccountsSqlDatabases | None = ...,
        database_accounts_sql_databases_containers: collections.abc.Iterable[global___DatabaseAccountsSqlDatabasesContainers] | None = ...,
        database_accounts_sql_databases_containers_stored_procedures: collections.abc.Iterable[global___DatabaseAccountsSqlDatabasesContainersStoredProcedures] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["database_accounts", b"database_accounts", "database_accounts_sql_databases", b"database_accounts_sql_databases"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["database_accounts", b"database_accounts", "database_accounts_cassandra_keyspaces", b"database_accounts_cassandra_keyspaces", "database_accounts_cassandra_keyspaces_tables", b"database_accounts_cassandra_keyspaces_tables", "database_accounts_gremlin_databases_graphs", b"database_accounts_gremlin_databases_graphs", "database_accounts_sql_databases", b"database_accounts_sql_databases", "database_accounts_sql_databases_containers", b"database_accounts_sql_databases_containers", "database_accounts_sql_databases_containers_stored_procedures", b"database_accounts_sql_databases_containers_stored_procedures"]) -> None: ...

global___Microsoft_DocumentDB = Microsoft_DocumentDB

@typing_extensions.final
class DatabaseAccountsTablesThroughputSettings(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class TagsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    IDENTITY_FIELD_NUMBER: builtins.int
    LOCATION_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    RESOURCE_FIELD_NUMBER: builtins.int
    TAGS_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    @property
    def identity(self) -> global___ManagedServiceIdentity: ...
    location: builtins.str
    name: builtins.str
    @property
    def resource(self) -> global___ThroughputSettingsResource: ...
    @property
    def tags(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        identity: global___ManagedServiceIdentity | None = ...,
        location: builtins.str = ...,
        name: builtins.str = ...,
        resource: global___ThroughputSettingsResource | None = ...,
        tags: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["identity", b"identity", "resource", b"resource", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["identity", b"identity", "location", b"location", "name", b"name", "resource", b"resource", "resource_info", b"resource_info", "tags", b"tags"]) -> None: ...

global___DatabaseAccountsTablesThroughputSettings = DatabaseAccountsTablesThroughputSettings

@typing_extensions.final
class DatabaseAccountsTables(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class TagsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    IDENTITY_FIELD_NUMBER: builtins.int
    LOCATION_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    OPTIONS_FIELD_NUMBER: builtins.int
    RESOURCE_FIELD_NUMBER: builtins.int
    TAGS_FIELD_NUMBER: builtins.int
    DATABASE_ACCOUNTS_TABLES_THROUGHPUT_SETTINGS_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    @property
    def identity(self) -> global___ManagedServiceIdentity: ...
    location: builtins.str
    name: builtins.str
    @property
    def options(self) -> global___CreateUpdateOptions: ...
    @property
    def resource(self) -> global___TableResource: ...
    @property
    def tags(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    @property
    def database_accounts_tables_throughput_settings(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___DatabaseAccountsTablesThroughputSettings]: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        identity: global___ManagedServiceIdentity | None = ...,
        location: builtins.str = ...,
        name: builtins.str = ...,
        options: global___CreateUpdateOptions | None = ...,
        resource: global___TableResource | None = ...,
        tags: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        database_accounts_tables_throughput_settings: collections.abc.Iterable[global___DatabaseAccountsTablesThroughputSettings] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["identity", b"identity", "options", b"options", "resource", b"resource", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["database_accounts_tables_throughput_settings", b"database_accounts_tables_throughput_settings", "identity", b"identity", "location", b"location", "name", b"name", "options", b"options", "resource", b"resource", "resource_info", b"resource_info", "tags", b"tags"]) -> None: ...

global___DatabaseAccountsTables = DatabaseAccountsTables

@typing_extensions.final
class TableResource(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ID_FIELD_NUMBER: builtins.int
    id: builtins.str
    def __init__(
        self,
        *,
        id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["id", b"id"]) -> None: ...

global___TableResource = TableResource

@typing_extensions.final
class DatabaseAccountsSqlRoleDefinitions(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    ASSIGNABLE_SCOPES_FIELD_NUMBER: builtins.int
    PERMISSIONS_FIELD_NUMBER: builtins.int
    ROLE_NAME_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    name: builtins.str
    @property
    def assignable_scopes(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def permissions(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Permission]: ...
    role_name: builtins.str
    type: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        name: builtins.str = ...,
        assignable_scopes: collections.abc.Iterable[builtins.str] | None = ...,
        permissions: collections.abc.Iterable[global___Permission] | None = ...,
        role_name: builtins.str = ...,
        type: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["assignable_scopes", b"assignable_scopes", "name", b"name", "permissions", b"permissions", "resource_info", b"resource_info", "role_name", b"role_name", "type", b"type"]) -> None: ...

global___DatabaseAccountsSqlRoleDefinitions = DatabaseAccountsSqlRoleDefinitions

@typing_extensions.final
class Permission(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DATA_ACTIONS_FIELD_NUMBER: builtins.int
    NOT_DATA_ACTIONS_FIELD_NUMBER: builtins.int
    @property
    def data_actions(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def not_data_actions(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    def __init__(
        self,
        *,
        data_actions: collections.abc.Iterable[builtins.str] | None = ...,
        not_data_actions: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["data_actions", b"data_actions", "not_data_actions", b"not_data_actions"]) -> None: ...

global___Permission = Permission

@typing_extensions.final
class DatabaseAccountsSqlRoleAssignments(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    PRINCIPAL_ID_FIELD_NUMBER: builtins.int
    ROLE_DEFINITION_ID_FIELD_NUMBER: builtins.int
    SCOPE_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    name: builtins.str
    principal_id: builtins.str
    role_definition_id: builtins.str
    scope: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        name: builtins.str = ...,
        principal_id: builtins.str = ...,
        role_definition_id: builtins.str = ...,
        scope: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["name", b"name", "principal_id", b"principal_id", "resource_info", b"resource_info", "role_definition_id", b"role_definition_id", "scope", b"scope"]) -> None: ...

global___DatabaseAccountsSqlRoleAssignments = DatabaseAccountsSqlRoleAssignments

@typing_extensions.final
class DatabaseAccountsSqlDatabasesThroughputSettings(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class TagsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    IDENTITY_FIELD_NUMBER: builtins.int
    LOCATION_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    RESOURCE_FIELD_NUMBER: builtins.int
    TAGS_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    @property
    def identity(self) -> global___ManagedServiceIdentity: ...
    location: builtins.str
    name: builtins.str
    @property
    def resource(self) -> global___ThroughputSettingsResource: ...
    @property
    def tags(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        identity: global___ManagedServiceIdentity | None = ...,
        location: builtins.str = ...,
        name: builtins.str = ...,
        resource: global___ThroughputSettingsResource | None = ...,
        tags: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["identity", b"identity", "resource", b"resource", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["identity", b"identity", "location", b"location", "name", b"name", "resource", b"resource", "resource_info", b"resource_info", "tags", b"tags"]) -> None: ...

global___DatabaseAccountsSqlDatabasesThroughputSettings = DatabaseAccountsSqlDatabasesThroughputSettings

@typing_extensions.final
class DatabaseAccountsSqlDatabasesContainersUserDefinedFunctions(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class TagsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    IDENTITY_FIELD_NUMBER: builtins.int
    LOCATION_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    OPTIONS_FIELD_NUMBER: builtins.int
    RESOURCE_FIELD_NUMBER: builtins.int
    TAGS_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    @property
    def identity(self) -> global___ManagedServiceIdentity: ...
    location: builtins.str
    name: builtins.str
    @property
    def options(self) -> global___CreateUpdateOptions: ...
    @property
    def resource(self) -> global___SqlUserDefinedFunctionResource: ...
    @property
    def tags(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        identity: global___ManagedServiceIdentity | None = ...,
        location: builtins.str = ...,
        name: builtins.str = ...,
        options: global___CreateUpdateOptions | None = ...,
        resource: global___SqlUserDefinedFunctionResource | None = ...,
        tags: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["identity", b"identity", "options", b"options", "resource", b"resource", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["identity", b"identity", "location", b"location", "name", b"name", "options", b"options", "resource", b"resource", "resource_info", b"resource_info", "tags", b"tags"]) -> None: ...

global___DatabaseAccountsSqlDatabasesContainersUserDefinedFunctions = DatabaseAccountsSqlDatabasesContainersUserDefinedFunctions

@typing_extensions.final
class SqlUserDefinedFunctionResource(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BODY_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    body: builtins.str
    id: builtins.str
    def __init__(
        self,
        *,
        body: builtins.str = ...,
        id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["body", b"body", "id", b"id"]) -> None: ...

global___SqlUserDefinedFunctionResource = SqlUserDefinedFunctionResource

@typing_extensions.final
class DatabaseAccountsSqlDatabasesContainersTriggers(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class TagsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    IDENTITY_FIELD_NUMBER: builtins.int
    LOCATION_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    OPTIONS_FIELD_NUMBER: builtins.int
    RESOURCE_FIELD_NUMBER: builtins.int
    TAGS_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    @property
    def identity(self) -> global___ManagedServiceIdentity: ...
    location: builtins.str
    name: builtins.str
    @property
    def options(self) -> global___CreateUpdateOptions: ...
    @property
    def resource(self) -> global___SqlTriggerResource: ...
    @property
    def tags(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        identity: global___ManagedServiceIdentity | None = ...,
        location: builtins.str = ...,
        name: builtins.str = ...,
        options: global___CreateUpdateOptions | None = ...,
        resource: global___SqlTriggerResource | None = ...,
        tags: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["identity", b"identity", "options", b"options", "resource", b"resource", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["identity", b"identity", "location", b"location", "name", b"name", "options", b"options", "resource", b"resource", "resource_info", b"resource_info", "tags", b"tags"]) -> None: ...

global___DatabaseAccountsSqlDatabasesContainersTriggers = DatabaseAccountsSqlDatabasesContainersTriggers

@typing_extensions.final
class SqlTriggerResource(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BODY_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    TRIGGER_OPERATION_FIELD_NUMBER: builtins.int
    TRIGGER_TYPE_FIELD_NUMBER: builtins.int
    body: builtins.str
    id: builtins.str
    trigger_operation: builtins.str
    trigger_type: builtins.str
    def __init__(
        self,
        *,
        body: builtins.str = ...,
        id: builtins.str = ...,
        trigger_operation: builtins.str = ...,
        trigger_type: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["body", b"body", "id", b"id", "trigger_operation", b"trigger_operation", "trigger_type", b"trigger_type"]) -> None: ...

global___SqlTriggerResource = SqlTriggerResource

@typing_extensions.final
class DatabaseAccountsSqlDatabasesContainersThroughputSettings(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class TagsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    IDENTITY_FIELD_NUMBER: builtins.int
    LOCATION_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    RESOURCE_FIELD_NUMBER: builtins.int
    TAGS_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    @property
    def identity(self) -> global___ManagedServiceIdentity: ...
    location: builtins.str
    name: builtins.str
    @property
    def resource(self) -> global___ThroughputSettingsResource: ...
    @property
    def tags(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        identity: global___ManagedServiceIdentity | None = ...,
        location: builtins.str = ...,
        name: builtins.str = ...,
        resource: global___ThroughputSettingsResource | None = ...,
        tags: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["identity", b"identity", "resource", b"resource", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["identity", b"identity", "location", b"location", "name", b"name", "resource", b"resource", "resource_info", b"resource_info", "tags", b"tags"]) -> None: ...

global___DatabaseAccountsSqlDatabasesContainersThroughputSettings = DatabaseAccountsSqlDatabasesContainersThroughputSettings

@typing_extensions.final
class DatabaseAccountsSqlDatabasesContainersStoredProcedures(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class TagsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    IDENTITY_FIELD_NUMBER: builtins.int
    LOCATION_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    OPTIONS_FIELD_NUMBER: builtins.int
    RESOURCE_FIELD_NUMBER: builtins.int
    TAGS_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    @property
    def identity(self) -> global___ManagedServiceIdentity: ...
    location: builtins.str
    name: builtins.str
    @property
    def options(self) -> global___CreateUpdateOptions: ...
    @property
    def resource(self) -> global___SqlStoredProcedureResource: ...
    @property
    def tags(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        identity: global___ManagedServiceIdentity | None = ...,
        location: builtins.str = ...,
        name: builtins.str = ...,
        options: global___CreateUpdateOptions | None = ...,
        resource: global___SqlStoredProcedureResource | None = ...,
        tags: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["identity", b"identity", "options", b"options", "resource", b"resource", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["identity", b"identity", "location", b"location", "name", b"name", "options", b"options", "resource", b"resource", "resource_info", b"resource_info", "tags", b"tags"]) -> None: ...

global___DatabaseAccountsSqlDatabasesContainersStoredProcedures = DatabaseAccountsSqlDatabasesContainersStoredProcedures

@typing_extensions.final
class SqlStoredProcedureResource(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BODY_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    body: builtins.str
    id: builtins.str
    def __init__(
        self,
        *,
        body: builtins.str = ...,
        id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["body", b"body", "id", b"id"]) -> None: ...

global___SqlStoredProcedureResource = SqlStoredProcedureResource

@typing_extensions.final
class DatabaseAccountsSqlDatabasesContainers(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class TagsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    IDENTITY_FIELD_NUMBER: builtins.int
    LOCATION_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    OPTIONS_FIELD_NUMBER: builtins.int
    RESOURCE_FIELD_NUMBER: builtins.int
    TAGS_FIELD_NUMBER: builtins.int
    DATABASE_ACCOUNTS_SQL_DATABASES_CONTAINERS_THROUGHPUT_SETTINGS_FIELD_NUMBER: builtins.int
    DATABASE_ACCOUNTS_SQL_DATABASES_CONTAINERS_USER_DEFINED_FUNCTIONS_FIELD_NUMBER: builtins.int
    DATABASE_ACCOUNTS_SQL_DATABASES_CONTAINERS_TRIGGERS_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    @property
    def identity(self) -> global___ManagedServiceIdentity: ...
    location: builtins.str
    name: builtins.str
    @property
    def options(self) -> global___CreateUpdateOptions: ...
    @property
    def resource(self) -> global___SqlContainerResource: ...
    @property
    def tags(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    @property
    def database_accounts_sql_databases_containers_throughput_settings(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___DatabaseAccountsSqlDatabasesContainersThroughputSettings]: ...
    @property
    def database_accounts_sql_databases_containers_user_defined_functions(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___DatabaseAccountsSqlDatabasesContainersUserDefinedFunctions]: ...
    @property
    def database_accounts_sql_databases_containers_triggers(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___DatabaseAccountsSqlDatabasesContainersTriggers]: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        identity: global___ManagedServiceIdentity | None = ...,
        location: builtins.str = ...,
        name: builtins.str = ...,
        options: global___CreateUpdateOptions | None = ...,
        resource: global___SqlContainerResource | None = ...,
        tags: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        database_accounts_sql_databases_containers_throughput_settings: collections.abc.Iterable[global___DatabaseAccountsSqlDatabasesContainersThroughputSettings] | None = ...,
        database_accounts_sql_databases_containers_user_defined_functions: collections.abc.Iterable[global___DatabaseAccountsSqlDatabasesContainersUserDefinedFunctions] | None = ...,
        database_accounts_sql_databases_containers_triggers: collections.abc.Iterable[global___DatabaseAccountsSqlDatabasesContainersTriggers] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["identity", b"identity", "options", b"options", "resource", b"resource", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["database_accounts_sql_databases_containers_throughput_settings", b"database_accounts_sql_databases_containers_throughput_settings", "database_accounts_sql_databases_containers_triggers", b"database_accounts_sql_databases_containers_triggers", "database_accounts_sql_databases_containers_user_defined_functions", b"database_accounts_sql_databases_containers_user_defined_functions", "identity", b"identity", "location", b"location", "name", b"name", "options", b"options", "resource", b"resource", "resource_info", b"resource_info", "tags", b"tags"]) -> None: ...

global___DatabaseAccountsSqlDatabasesContainers = DatabaseAccountsSqlDatabasesContainers

@typing_extensions.final
class SqlContainerResource(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ANALYTICAL_STORAGE_TTL_FIELD_NUMBER: builtins.int
    CONFLICT_RESOLUTION_POLICY_FIELD_NUMBER: builtins.int
    DEFAULT_TTL_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    INDEXING_POLICY_FIELD_NUMBER: builtins.int
    PARTITION_KEY_FIELD_NUMBER: builtins.int
    UNIQUE_KEY_POLICY_FIELD_NUMBER: builtins.int
    analytical_storage_ttl: builtins.int
    @property
    def conflict_resolution_policy(self) -> global___ConflictResolutionPolicy: ...
    default_ttl: builtins.int
    id: builtins.str
    @property
    def indexing_policy(self) -> global___IndexingPolicy: ...
    @property
    def partition_key(self) -> global___ContainerPartitionKey: ...
    @property
    def unique_key_policy(self) -> global___UniqueKeyPolicy: ...
    def __init__(
        self,
        *,
        analytical_storage_ttl: builtins.int = ...,
        conflict_resolution_policy: global___ConflictResolutionPolicy | None = ...,
        default_ttl: builtins.int = ...,
        id: builtins.str = ...,
        indexing_policy: global___IndexingPolicy | None = ...,
        partition_key: global___ContainerPartitionKey | None = ...,
        unique_key_policy: global___UniqueKeyPolicy | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["conflict_resolution_policy", b"conflict_resolution_policy", "indexing_policy", b"indexing_policy", "partition_key", b"partition_key", "unique_key_policy", b"unique_key_policy"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["analytical_storage_ttl", b"analytical_storage_ttl", "conflict_resolution_policy", b"conflict_resolution_policy", "default_ttl", b"default_ttl", "id", b"id", "indexing_policy", b"indexing_policy", "partition_key", b"partition_key", "unique_key_policy", b"unique_key_policy"]) -> None: ...

global___SqlContainerResource = SqlContainerResource

@typing_extensions.final
class DatabaseAccountsSqlDatabasesClientEncryptionKeys(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    RESOURCE_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    name: builtins.str
    @property
    def resource(self) -> global___ClientEncryptionKeyResource: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        name: builtins.str = ...,
        resource: global___ClientEncryptionKeyResource | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource", b"resource", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["name", b"name", "resource", b"resource", "resource_info", b"resource_info"]) -> None: ...

global___DatabaseAccountsSqlDatabasesClientEncryptionKeys = DatabaseAccountsSqlDatabasesClientEncryptionKeys

@typing_extensions.final
class ClientEncryptionKeyResource(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ENCRYPTION_ALGORITHM_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    KEY_WRAP_METADATA_FIELD_NUMBER: builtins.int
    WRAPPED_DATA_ENCRYPTION_KEY_FIELD_NUMBER: builtins.int
    encryption_algorithm: builtins.str
    id: builtins.str
    @property
    def key_wrap_metadata(self) -> global___KeyWrapMetadata: ...
    wrapped_data_encryption_key: builtins.str
    def __init__(
        self,
        *,
        encryption_algorithm: builtins.str = ...,
        id: builtins.str = ...,
        key_wrap_metadata: global___KeyWrapMetadata | None = ...,
        wrapped_data_encryption_key: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["key_wrap_metadata", b"key_wrap_metadata"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["encryption_algorithm", b"encryption_algorithm", "id", b"id", "key_wrap_metadata", b"key_wrap_metadata", "wrapped_data_encryption_key", b"wrapped_data_encryption_key"]) -> None: ...

global___ClientEncryptionKeyResource = ClientEncryptionKeyResource

@typing_extensions.final
class KeyWrapMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ALGORITHM_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    VALUE_FIELD_NUMBER: builtins.int
    algorithm: builtins.str
    name: builtins.str
    type: builtins.str
    value: builtins.str
    def __init__(
        self,
        *,
        algorithm: builtins.str = ...,
        name: builtins.str = ...,
        type: builtins.str = ...,
        value: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["algorithm", b"algorithm", "name", b"name", "type", b"type", "value", b"value"]) -> None: ...

global___KeyWrapMetadata = KeyWrapMetadata

@typing_extensions.final
class DatabaseAccountsSqlDatabases(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class TagsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    IDENTITY_FIELD_NUMBER: builtins.int
    LOCATION_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    OPTIONS_FIELD_NUMBER: builtins.int
    RESOURCE_FIELD_NUMBER: builtins.int
    TAGS_FIELD_NUMBER: builtins.int
    DATABASE_ACCOUNTS_SQL_DATABASES_THROUGHPUT_SETTINGS_FIELD_NUMBER: builtins.int
    DATABASE_ACCOUNTS_SQL_DATABASES_CLIENT_ENCRYPTION_KEYS_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    @property
    def identity(self) -> global___ManagedServiceIdentity: ...
    location: builtins.str
    name: builtins.str
    @property
    def options(self) -> global___CreateUpdateOptions: ...
    @property
    def resource(self) -> global___SqlDatabaseResource: ...
    @property
    def tags(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    @property
    def database_accounts_sql_databases_throughput_settings(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___DatabaseAccountsSqlDatabasesThroughputSettings]: ...
    @property
    def database_accounts_sql_databases_client_encryption_keys(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___DatabaseAccountsSqlDatabasesClientEncryptionKeys]: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        identity: global___ManagedServiceIdentity | None = ...,
        location: builtins.str = ...,
        name: builtins.str = ...,
        options: global___CreateUpdateOptions | None = ...,
        resource: global___SqlDatabaseResource | None = ...,
        tags: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        database_accounts_sql_databases_throughput_settings: collections.abc.Iterable[global___DatabaseAccountsSqlDatabasesThroughputSettings] | None = ...,
        database_accounts_sql_databases_client_encryption_keys: collections.abc.Iterable[global___DatabaseAccountsSqlDatabasesClientEncryptionKeys] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["identity", b"identity", "options", b"options", "resource", b"resource", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["database_accounts_sql_databases_client_encryption_keys", b"database_accounts_sql_databases_client_encryption_keys", "database_accounts_sql_databases_throughput_settings", b"database_accounts_sql_databases_throughput_settings", "identity", b"identity", "location", b"location", "name", b"name", "options", b"options", "resource", b"resource", "resource_info", b"resource_info", "tags", b"tags"]) -> None: ...

global___DatabaseAccountsSqlDatabases = DatabaseAccountsSqlDatabases

@typing_extensions.final
class SqlDatabaseResource(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ID_FIELD_NUMBER: builtins.int
    id: builtins.str
    def __init__(
        self,
        *,
        id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["id", b"id"]) -> None: ...

global___SqlDatabaseResource = SqlDatabaseResource

@typing_extensions.final
class DatabaseAccountsServices(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    INSTANCE_COUNT_FIELD_NUMBER: builtins.int
    INSTANCE_SIZE_FIELD_NUMBER: builtins.int
    SERVICE_TYPE_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    name: builtins.str
    instance_count: builtins.int
    instance_size: builtins.str
    service_type: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        name: builtins.str = ...,
        instance_count: builtins.int = ...,
        instance_size: builtins.str = ...,
        service_type: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["instance_count", b"instance_count", "instance_size", b"instance_size", "name", b"name", "resource_info", b"resource_info", "service_type", b"service_type"]) -> None: ...

global___DatabaseAccountsServices = DatabaseAccountsServices

@typing_extensions.final
class DatabaseAccountsPrivateEndpointConnections(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    GROUP_ID_FIELD_NUMBER: builtins.int
    PRIVATE_ENDPOINT_FIELD_NUMBER: builtins.int
    PRIVATE_LINK_SERVICE_CONNECTION_STATE_FIELD_NUMBER: builtins.int
    PROVISIONING_STATE_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    name: builtins.str
    group_id: builtins.str
    @property
    def private_endpoint(self) -> global___PrivateEndpointProperty: ...
    @property
    def private_link_service_connection_state(self) -> global___PrivateLinkServiceConnectionStateProperty: ...
    provisioning_state: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        name: builtins.str = ...,
        group_id: builtins.str = ...,
        private_endpoint: global___PrivateEndpointProperty | None = ...,
        private_link_service_connection_state: global___PrivateLinkServiceConnectionStateProperty | None = ...,
        provisioning_state: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["private_endpoint", b"private_endpoint", "private_link_service_connection_state", b"private_link_service_connection_state", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["group_id", b"group_id", "name", b"name", "private_endpoint", b"private_endpoint", "private_link_service_connection_state", b"private_link_service_connection_state", "provisioning_state", b"provisioning_state", "resource_info", b"resource_info"]) -> None: ...

global___DatabaseAccountsPrivateEndpointConnections = DatabaseAccountsPrivateEndpointConnections

@typing_extensions.final
class PrivateLinkServiceConnectionStateProperty(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DESCRIPTION_FIELD_NUMBER: builtins.int
    STATUS_FIELD_NUMBER: builtins.int
    description: builtins.str
    status: builtins.str
    def __init__(
        self,
        *,
        description: builtins.str = ...,
        status: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["description", b"description", "status", b"status"]) -> None: ...

global___PrivateLinkServiceConnectionStateProperty = PrivateLinkServiceConnectionStateProperty

@typing_extensions.final
class PrivateEndpointProperty(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ID_FIELD_NUMBER: builtins.int
    id: builtins.str
    def __init__(
        self,
        *,
        id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["id", b"id"]) -> None: ...

global___PrivateEndpointProperty = PrivateEndpointProperty

@typing_extensions.final
class DatabaseAccountsNotebookWorkspaces(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    name: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        name: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["name", b"name", "resource_info", b"resource_info"]) -> None: ...

global___DatabaseAccountsNotebookWorkspaces = DatabaseAccountsNotebookWorkspaces

@typing_extensions.final
class DatabaseAccountsMongodbUserDefinitions(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    CUSTOM_DATA_FIELD_NUMBER: builtins.int
    DATABASE_NAME_FIELD_NUMBER: builtins.int
    MECHANISMS_FIELD_NUMBER: builtins.int
    PASSWORD_FIELD_NUMBER: builtins.int
    ROLES_FIELD_NUMBER: builtins.int
    USER_NAME_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    name: builtins.str
    custom_data: builtins.str
    database_name: builtins.str
    mechanisms: builtins.str
    password: builtins.str
    @property
    def roles(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Role]: ...
    user_name: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        name: builtins.str = ...,
        custom_data: builtins.str = ...,
        database_name: builtins.str = ...,
        mechanisms: builtins.str = ...,
        password: builtins.str = ...,
        roles: collections.abc.Iterable[global___Role] | None = ...,
        user_name: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["custom_data", b"custom_data", "database_name", b"database_name", "mechanisms", b"mechanisms", "name", b"name", "password", b"password", "resource_info", b"resource_info", "roles", b"roles", "user_name", b"user_name"]) -> None: ...

global___DatabaseAccountsMongodbUserDefinitions = DatabaseAccountsMongodbUserDefinitions

@typing_extensions.final
class DatabaseAccountsMongodbRoleDefinitions(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    DATABASE_NAME_FIELD_NUMBER: builtins.int
    PRIVILEGES_FIELD_NUMBER: builtins.int
    ROLE_NAME_FIELD_NUMBER: builtins.int
    ROLES_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    name: builtins.str
    database_name: builtins.str
    @property
    def privileges(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Privilege]: ...
    role_name: builtins.str
    @property
    def roles(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Role]: ...
    type: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        name: builtins.str = ...,
        database_name: builtins.str = ...,
        privileges: collections.abc.Iterable[global___Privilege] | None = ...,
        role_name: builtins.str = ...,
        roles: collections.abc.Iterable[global___Role] | None = ...,
        type: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["database_name", b"database_name", "name", b"name", "privileges", b"privileges", "resource_info", b"resource_info", "role_name", b"role_name", "roles", b"roles", "type", b"type"]) -> None: ...

global___DatabaseAccountsMongodbRoleDefinitions = DatabaseAccountsMongodbRoleDefinitions

@typing_extensions.final
class Role(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DB_FIELD_NUMBER: builtins.int
    ROLE_FIELD_NUMBER: builtins.int
    db: builtins.str
    role: builtins.str
    def __init__(
        self,
        *,
        db: builtins.str = ...,
        role: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["db", b"db", "role", b"role"]) -> None: ...

global___Role = Role

@typing_extensions.final
class Privilege(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ACTIONS_FIELD_NUMBER: builtins.int
    RESOURCE_FIELD_NUMBER: builtins.int
    @property
    def actions(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def resource(self) -> global___PrivilegeResource: ...
    def __init__(
        self,
        *,
        actions: collections.abc.Iterable[builtins.str] | None = ...,
        resource: global___PrivilegeResource | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource", b"resource"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["actions", b"actions", "resource", b"resource"]) -> None: ...

global___Privilege = Privilege

@typing_extensions.final
class PrivilegeResource(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    COLLECTION_FIELD_NUMBER: builtins.int
    DB_FIELD_NUMBER: builtins.int
    collection: builtins.str
    db: builtins.str
    def __init__(
        self,
        *,
        collection: builtins.str = ...,
        db: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["collection", b"collection", "db", b"db"]) -> None: ...

global___PrivilegeResource = PrivilegeResource

@typing_extensions.final
class DatabaseAccountsMongodbDatabasesThroughputSettings(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class TagsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    IDENTITY_FIELD_NUMBER: builtins.int
    LOCATION_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    RESOURCE_FIELD_NUMBER: builtins.int
    TAGS_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    @property
    def identity(self) -> global___ManagedServiceIdentity: ...
    location: builtins.str
    name: builtins.str
    @property
    def resource(self) -> global___ThroughputSettingsResource: ...
    @property
    def tags(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        identity: global___ManagedServiceIdentity | None = ...,
        location: builtins.str = ...,
        name: builtins.str = ...,
        resource: global___ThroughputSettingsResource | None = ...,
        tags: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["identity", b"identity", "resource", b"resource", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["identity", b"identity", "location", b"location", "name", b"name", "resource", b"resource", "resource_info", b"resource_info", "tags", b"tags"]) -> None: ...

global___DatabaseAccountsMongodbDatabasesThroughputSettings = DatabaseAccountsMongodbDatabasesThroughputSettings

@typing_extensions.final
class DatabaseAccountsMongodbDatabasesCollectionsThroughputSettings(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class TagsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    IDENTITY_FIELD_NUMBER: builtins.int
    LOCATION_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    RESOURCE_FIELD_NUMBER: builtins.int
    TAGS_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    @property
    def identity(self) -> global___ManagedServiceIdentity: ...
    location: builtins.str
    name: builtins.str
    @property
    def resource(self) -> global___ThroughputSettingsResource: ...
    @property
    def tags(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        identity: global___ManagedServiceIdentity | None = ...,
        location: builtins.str = ...,
        name: builtins.str = ...,
        resource: global___ThroughputSettingsResource | None = ...,
        tags: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["identity", b"identity", "resource", b"resource", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["identity", b"identity", "location", b"location", "name", b"name", "resource", b"resource", "resource_info", b"resource_info", "tags", b"tags"]) -> None: ...

global___DatabaseAccountsMongodbDatabasesCollectionsThroughputSettings = DatabaseAccountsMongodbDatabasesCollectionsThroughputSettings

@typing_extensions.final
class DatabaseAccountsMongodbDatabasesCollections(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class TagsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    IDENTITY_FIELD_NUMBER: builtins.int
    LOCATION_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    OPTIONS_FIELD_NUMBER: builtins.int
    RESOURCE_FIELD_NUMBER: builtins.int
    TAGS_FIELD_NUMBER: builtins.int
    DATABASE_ACCOUNTS_MONGODB_DATABASES_COLLECTIONS_THROUGHPUT_SETTINGS_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    @property
    def identity(self) -> global___ManagedServiceIdentity: ...
    location: builtins.str
    name: builtins.str
    @property
    def options(self) -> global___CreateUpdateOptions: ...
    @property
    def resource(self) -> global___MongoDBCollectionResource: ...
    @property
    def tags(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    @property
    def database_accounts_mongodb_databases_collections_throughput_settings(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___DatabaseAccountsMongodbDatabasesCollectionsThroughputSettings]: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        identity: global___ManagedServiceIdentity | None = ...,
        location: builtins.str = ...,
        name: builtins.str = ...,
        options: global___CreateUpdateOptions | None = ...,
        resource: global___MongoDBCollectionResource | None = ...,
        tags: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        database_accounts_mongodb_databases_collections_throughput_settings: collections.abc.Iterable[global___DatabaseAccountsMongodbDatabasesCollectionsThroughputSettings] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["identity", b"identity", "options", b"options", "resource", b"resource", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["database_accounts_mongodb_databases_collections_throughput_settings", b"database_accounts_mongodb_databases_collections_throughput_settings", "identity", b"identity", "location", b"location", "name", b"name", "options", b"options", "resource", b"resource", "resource_info", b"resource_info", "tags", b"tags"]) -> None: ...

global___DatabaseAccountsMongodbDatabasesCollections = DatabaseAccountsMongodbDatabasesCollections

@typing_extensions.final
class MongoDBCollectionResource(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class ShardKeyEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    ANALYTICAL_STORAGE_TTL_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    INDEXES_FIELD_NUMBER: builtins.int
    SHARD_KEY_FIELD_NUMBER: builtins.int
    analytical_storage_ttl: builtins.int
    id: builtins.str
    @property
    def indexes(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___MongoIndex]: ...
    @property
    def shard_key(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    def __init__(
        self,
        *,
        analytical_storage_ttl: builtins.int = ...,
        id: builtins.str = ...,
        indexes: collections.abc.Iterable[global___MongoIndex] | None = ...,
        shard_key: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["analytical_storage_ttl", b"analytical_storage_ttl", "id", b"id", "indexes", b"indexes", "shard_key", b"shard_key"]) -> None: ...

global___MongoDBCollectionResource = MongoDBCollectionResource

@typing_extensions.final
class MongoIndex(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    KEY_FIELD_NUMBER: builtins.int
    OPTIONS_FIELD_NUMBER: builtins.int
    @property
    def key(self) -> global___MongoIndexKeys: ...
    @property
    def options(self) -> global___MongoIndexOptions: ...
    def __init__(
        self,
        *,
        key: global___MongoIndexKeys | None = ...,
        options: global___MongoIndexOptions | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["key", b"key", "options", b"options"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "options", b"options"]) -> None: ...

global___MongoIndex = MongoIndex

@typing_extensions.final
class MongoIndexOptions(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EXPIRE_AFTER_SECONDS_FIELD_NUMBER: builtins.int
    UNIQUE_FIELD_NUMBER: builtins.int
    expire_after_seconds: builtins.int
    unique: builtins.bool
    def __init__(
        self,
        *,
        expire_after_seconds: builtins.int = ...,
        unique: builtins.bool = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["expire_after_seconds", b"expire_after_seconds", "unique", b"unique"]) -> None: ...

global___MongoIndexOptions = MongoIndexOptions

@typing_extensions.final
class MongoIndexKeys(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    KEYS_FIELD_NUMBER: builtins.int
    @property
    def keys(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    def __init__(
        self,
        *,
        keys: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["keys", b"keys"]) -> None: ...

global___MongoIndexKeys = MongoIndexKeys

@typing_extensions.final
class DatabaseAccountsMongodbDatabases(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class TagsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    IDENTITY_FIELD_NUMBER: builtins.int
    LOCATION_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    OPTIONS_FIELD_NUMBER: builtins.int
    RESOURCE_FIELD_NUMBER: builtins.int
    TAGS_FIELD_NUMBER: builtins.int
    DATABASE_ACCOUNTS_MONGODB_DATABASES_THROUGHPUT_SETTINGS_FIELD_NUMBER: builtins.int
    DATABASE_ACCOUNTS_MONGODB_DATABASES_COLLECTIONS_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    @property
    def identity(self) -> global___ManagedServiceIdentity: ...
    location: builtins.str
    name: builtins.str
    @property
    def options(self) -> global___CreateUpdateOptions: ...
    @property
    def resource(self) -> global___MongoDBDatabaseResource: ...
    @property
    def tags(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    @property
    def database_accounts_mongodb_databases_throughput_settings(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___DatabaseAccountsMongodbDatabasesThroughputSettings]: ...
    @property
    def database_accounts_mongodb_databases_collections(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___DatabaseAccountsMongodbDatabasesCollections]: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        identity: global___ManagedServiceIdentity | None = ...,
        location: builtins.str = ...,
        name: builtins.str = ...,
        options: global___CreateUpdateOptions | None = ...,
        resource: global___MongoDBDatabaseResource | None = ...,
        tags: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        database_accounts_mongodb_databases_throughput_settings: collections.abc.Iterable[global___DatabaseAccountsMongodbDatabasesThroughputSettings] | None = ...,
        database_accounts_mongodb_databases_collections: collections.abc.Iterable[global___DatabaseAccountsMongodbDatabasesCollections] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["identity", b"identity", "options", b"options", "resource", b"resource", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["database_accounts_mongodb_databases_collections", b"database_accounts_mongodb_databases_collections", "database_accounts_mongodb_databases_throughput_settings", b"database_accounts_mongodb_databases_throughput_settings", "identity", b"identity", "location", b"location", "name", b"name", "options", b"options", "resource", b"resource", "resource_info", b"resource_info", "tags", b"tags"]) -> None: ...

global___DatabaseAccountsMongodbDatabases = DatabaseAccountsMongodbDatabases

@typing_extensions.final
class MongoDBDatabaseResource(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ID_FIELD_NUMBER: builtins.int
    id: builtins.str
    def __init__(
        self,
        *,
        id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["id", b"id"]) -> None: ...

global___MongoDBDatabaseResource = MongoDBDatabaseResource

@typing_extensions.final
class DatabaseAccountsGremlinDatabasesThroughputSettings(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class TagsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    IDENTITY_FIELD_NUMBER: builtins.int
    LOCATION_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    RESOURCE_FIELD_NUMBER: builtins.int
    TAGS_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    @property
    def identity(self) -> global___ManagedServiceIdentity: ...
    location: builtins.str
    name: builtins.str
    @property
    def resource(self) -> global___ThroughputSettingsResource: ...
    @property
    def tags(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        identity: global___ManagedServiceIdentity | None = ...,
        location: builtins.str = ...,
        name: builtins.str = ...,
        resource: global___ThroughputSettingsResource | None = ...,
        tags: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["identity", b"identity", "resource", b"resource", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["identity", b"identity", "location", b"location", "name", b"name", "resource", b"resource", "resource_info", b"resource_info", "tags", b"tags"]) -> None: ...

global___DatabaseAccountsGremlinDatabasesThroughputSettings = DatabaseAccountsGremlinDatabasesThroughputSettings

@typing_extensions.final
class DatabaseAccountsGremlinDatabasesGraphsThroughputSettings(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class TagsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    IDENTITY_FIELD_NUMBER: builtins.int
    LOCATION_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    RESOURCE_FIELD_NUMBER: builtins.int
    TAGS_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    @property
    def identity(self) -> global___ManagedServiceIdentity: ...
    location: builtins.str
    name: builtins.str
    @property
    def resource(self) -> global___ThroughputSettingsResource: ...
    @property
    def tags(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        identity: global___ManagedServiceIdentity | None = ...,
        location: builtins.str = ...,
        name: builtins.str = ...,
        resource: global___ThroughputSettingsResource | None = ...,
        tags: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["identity", b"identity", "resource", b"resource", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["identity", b"identity", "location", b"location", "name", b"name", "resource", b"resource", "resource_info", b"resource_info", "tags", b"tags"]) -> None: ...

global___DatabaseAccountsGremlinDatabasesGraphsThroughputSettings = DatabaseAccountsGremlinDatabasesGraphsThroughputSettings

@typing_extensions.final
class DatabaseAccountsGremlinDatabasesGraphs(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class TagsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    IDENTITY_FIELD_NUMBER: builtins.int
    LOCATION_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    OPTIONS_FIELD_NUMBER: builtins.int
    RESOURCE_FIELD_NUMBER: builtins.int
    TAGS_FIELD_NUMBER: builtins.int
    DATABASE_ACCOUNTS_GREMLIN_DATABASES_GRAPHS_THROUGHPUT_SETTINGS_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    @property
    def identity(self) -> global___ManagedServiceIdentity: ...
    location: builtins.str
    name: builtins.str
    @property
    def options(self) -> global___CreateUpdateOptions: ...
    @property
    def resource(self) -> global___GremlinGraphResource: ...
    @property
    def tags(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    @property
    def database_accounts_gremlin_databases_graphs_throughput_settings(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___DatabaseAccountsGremlinDatabasesGraphsThroughputSettings]: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        identity: global___ManagedServiceIdentity | None = ...,
        location: builtins.str = ...,
        name: builtins.str = ...,
        options: global___CreateUpdateOptions | None = ...,
        resource: global___GremlinGraphResource | None = ...,
        tags: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        database_accounts_gremlin_databases_graphs_throughput_settings: collections.abc.Iterable[global___DatabaseAccountsGremlinDatabasesGraphsThroughputSettings] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["identity", b"identity", "options", b"options", "resource", b"resource", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["database_accounts_gremlin_databases_graphs_throughput_settings", b"database_accounts_gremlin_databases_graphs_throughput_settings", "identity", b"identity", "location", b"location", "name", b"name", "options", b"options", "resource", b"resource", "resource_info", b"resource_info", "tags", b"tags"]) -> None: ...

global___DatabaseAccountsGremlinDatabasesGraphs = DatabaseAccountsGremlinDatabasesGraphs

@typing_extensions.final
class GremlinGraphResource(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CONFLICT_RESOLUTION_POLICY_FIELD_NUMBER: builtins.int
    DEFAULT_TTL_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    INDEXING_POLICY_FIELD_NUMBER: builtins.int
    PARTITION_KEY_FIELD_NUMBER: builtins.int
    UNIQUE_KEY_POLICY_FIELD_NUMBER: builtins.int
    @property
    def conflict_resolution_policy(self) -> global___ConflictResolutionPolicy: ...
    default_ttl: builtins.int
    id: builtins.str
    @property
    def indexing_policy(self) -> global___IndexingPolicy: ...
    @property
    def partition_key(self) -> global___ContainerPartitionKey: ...
    @property
    def unique_key_policy(self) -> global___UniqueKeyPolicy: ...
    def __init__(
        self,
        *,
        conflict_resolution_policy: global___ConflictResolutionPolicy | None = ...,
        default_ttl: builtins.int = ...,
        id: builtins.str = ...,
        indexing_policy: global___IndexingPolicy | None = ...,
        partition_key: global___ContainerPartitionKey | None = ...,
        unique_key_policy: global___UniqueKeyPolicy | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["conflict_resolution_policy", b"conflict_resolution_policy", "indexing_policy", b"indexing_policy", "partition_key", b"partition_key", "unique_key_policy", b"unique_key_policy"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["conflict_resolution_policy", b"conflict_resolution_policy", "default_ttl", b"default_ttl", "id", b"id", "indexing_policy", b"indexing_policy", "partition_key", b"partition_key", "unique_key_policy", b"unique_key_policy"]) -> None: ...

global___GremlinGraphResource = GremlinGraphResource

@typing_extensions.final
class UniqueKeyPolicy(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    UNIQUE_KEYS_FIELD_NUMBER: builtins.int
    @property
    def unique_keys(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___UniqueKey]: ...
    def __init__(
        self,
        *,
        unique_keys: collections.abc.Iterable[global___UniqueKey] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["unique_keys", b"unique_keys"]) -> None: ...

global___UniqueKeyPolicy = UniqueKeyPolicy

@typing_extensions.final
class UniqueKey(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PATHS_FIELD_NUMBER: builtins.int
    @property
    def paths(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    def __init__(
        self,
        *,
        paths: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["paths", b"paths"]) -> None: ...

global___UniqueKey = UniqueKey

@typing_extensions.final
class ContainerPartitionKey(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    KIND_FIELD_NUMBER: builtins.int
    PATHS_FIELD_NUMBER: builtins.int
    VERSION_FIELD_NUMBER: builtins.int
    kind: builtins.str
    @property
    def paths(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    version: builtins.int
    def __init__(
        self,
        *,
        kind: builtins.str = ...,
        paths: collections.abc.Iterable[builtins.str] | None = ...,
        version: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["kind", b"kind", "paths", b"paths", "version", b"version"]) -> None: ...

global___ContainerPartitionKey = ContainerPartitionKey

@typing_extensions.final
class IndexingPolicy(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class CompositeIndexesEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    AUTOMATIC_FIELD_NUMBER: builtins.int
    COMPOSITE_INDEXES_FIELD_NUMBER: builtins.int
    EXCLUDED_PATHS_FIELD_NUMBER: builtins.int
    INCLUDED_PATHS_FIELD_NUMBER: builtins.int
    INDEXING_MODE_FIELD_NUMBER: builtins.int
    SPATIAL_INDEXES_FIELD_NUMBER: builtins.int
    automatic: builtins.bool
    @property
    def composite_indexes(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    @property
    def excluded_paths(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ExcludedPath]: ...
    @property
    def included_paths(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___IncludedPath]: ...
    indexing_mode: builtins.str
    @property
    def spatial_indexes(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___SpatialSpec]: ...
    def __init__(
        self,
        *,
        automatic: builtins.bool = ...,
        composite_indexes: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        excluded_paths: collections.abc.Iterable[global___ExcludedPath] | None = ...,
        included_paths: collections.abc.Iterable[global___IncludedPath] | None = ...,
        indexing_mode: builtins.str = ...,
        spatial_indexes: collections.abc.Iterable[global___SpatialSpec] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["automatic", b"automatic", "composite_indexes", b"composite_indexes", "excluded_paths", b"excluded_paths", "included_paths", b"included_paths", "indexing_mode", b"indexing_mode", "spatial_indexes", b"spatial_indexes"]) -> None: ...

global___IndexingPolicy = IndexingPolicy

@typing_extensions.final
class SpatialSpec(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PATH_FIELD_NUMBER: builtins.int
    TYPES_FIELD_NUMBER: builtins.int
    path: builtins.str
    @property
    def types(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    def __init__(
        self,
        *,
        path: builtins.str = ...,
        types: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["path", b"path", "types", b"types"]) -> None: ...

global___SpatialSpec = SpatialSpec

@typing_extensions.final
class IncludedPath(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INDEXES_FIELD_NUMBER: builtins.int
    PATH_FIELD_NUMBER: builtins.int
    @property
    def indexes(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Indexes]: ...
    path: builtins.str
    def __init__(
        self,
        *,
        indexes: collections.abc.Iterable[global___Indexes] | None = ...,
        path: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["indexes", b"indexes", "path", b"path"]) -> None: ...

global___IncludedPath = IncludedPath

@typing_extensions.final
class Indexes(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DATA_TYPE_FIELD_NUMBER: builtins.int
    KIND_FIELD_NUMBER: builtins.int
    PRECISION_FIELD_NUMBER: builtins.int
    data_type: builtins.str
    kind: builtins.str
    precision: builtins.int
    def __init__(
        self,
        *,
        data_type: builtins.str = ...,
        kind: builtins.str = ...,
        precision: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["data_type", b"data_type", "kind", b"kind", "precision", b"precision"]) -> None: ...

global___Indexes = Indexes

@typing_extensions.final
class ExcludedPath(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PATH_FIELD_NUMBER: builtins.int
    path: builtins.str
    def __init__(
        self,
        *,
        path: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["path", b"path"]) -> None: ...

global___ExcludedPath = ExcludedPath

@typing_extensions.final
class ConflictResolutionPolicy(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CONFLICT_RESOLUTION_PATH_FIELD_NUMBER: builtins.int
    CONFLICT_RESOLUTION_PROCEDURE_FIELD_NUMBER: builtins.int
    MODE_FIELD_NUMBER: builtins.int
    conflict_resolution_path: builtins.str
    conflict_resolution_procedure: builtins.str
    mode: builtins.str
    def __init__(
        self,
        *,
        conflict_resolution_path: builtins.str = ...,
        conflict_resolution_procedure: builtins.str = ...,
        mode: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["conflict_resolution_path", b"conflict_resolution_path", "conflict_resolution_procedure", b"conflict_resolution_procedure", "mode", b"mode"]) -> None: ...

global___ConflictResolutionPolicy = ConflictResolutionPolicy

@typing_extensions.final
class DatabaseAccountsGremlinDatabases(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class TagsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    IDENTITY_FIELD_NUMBER: builtins.int
    LOCATION_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    OPTIONS_FIELD_NUMBER: builtins.int
    RESOURCE_FIELD_NUMBER: builtins.int
    TAGS_FIELD_NUMBER: builtins.int
    DATABASE_ACCOUNTS_GREMLIN_DATABASES_THROUGHPUT_SETTINGS_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    @property
    def identity(self) -> global___ManagedServiceIdentity: ...
    location: builtins.str
    name: builtins.str
    @property
    def options(self) -> global___CreateUpdateOptions: ...
    @property
    def resource(self) -> global___GremlinDatabaseResource: ...
    @property
    def tags(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    @property
    def database_accounts_gremlin_databases_throughput_settings(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___DatabaseAccountsGremlinDatabasesThroughputSettings]: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        identity: global___ManagedServiceIdentity | None = ...,
        location: builtins.str = ...,
        name: builtins.str = ...,
        options: global___CreateUpdateOptions | None = ...,
        resource: global___GremlinDatabaseResource | None = ...,
        tags: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        database_accounts_gremlin_databases_throughput_settings: collections.abc.Iterable[global___DatabaseAccountsGremlinDatabasesThroughputSettings] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["identity", b"identity", "options", b"options", "resource", b"resource", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["database_accounts_gremlin_databases_throughput_settings", b"database_accounts_gremlin_databases_throughput_settings", "identity", b"identity", "location", b"location", "name", b"name", "options", b"options", "resource", b"resource", "resource_info", b"resource_info", "tags", b"tags"]) -> None: ...

global___DatabaseAccountsGremlinDatabases = DatabaseAccountsGremlinDatabases

@typing_extensions.final
class GremlinDatabaseResource(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ID_FIELD_NUMBER: builtins.int
    id: builtins.str
    def __init__(
        self,
        *,
        id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["id", b"id"]) -> None: ...

global___GremlinDatabaseResource = GremlinDatabaseResource

@typing_extensions.final
class DatabaseAccountsGraphs(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class TagsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    IDENTITY_FIELD_NUMBER: builtins.int
    LOCATION_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    OPTIONS_FIELD_NUMBER: builtins.int
    RESOURCE_FIELD_NUMBER: builtins.int
    TAGS_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    @property
    def identity(self) -> global___ManagedServiceIdentity: ...
    location: builtins.str
    name: builtins.str
    @property
    def options(self) -> global___CreateUpdateOptions: ...
    @property
    def resource(self) -> global___GraphResource: ...
    @property
    def tags(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        identity: global___ManagedServiceIdentity | None = ...,
        location: builtins.str = ...,
        name: builtins.str = ...,
        options: global___CreateUpdateOptions | None = ...,
        resource: global___GraphResource | None = ...,
        tags: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["identity", b"identity", "options", b"options", "resource", b"resource", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["identity", b"identity", "location", b"location", "name", b"name", "options", b"options", "resource", b"resource", "resource_info", b"resource_info", "tags", b"tags"]) -> None: ...

global___DatabaseAccountsGraphs = DatabaseAccountsGraphs

@typing_extensions.final
class GraphResource(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ID_FIELD_NUMBER: builtins.int
    id: builtins.str
    def __init__(
        self,
        *,
        id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["id", b"id"]) -> None: ...

global___GraphResource = GraphResource

@typing_extensions.final
class DatabaseAccountsDataTransferJobs(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    DESTINATION_FIELD_NUMBER: builtins.int
    SOURCE_FIELD_NUMBER: builtins.int
    WORKER_COUNT_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    name: builtins.str
    @property
    def destination(self) -> global___DataTransferDataSourceSink: ...
    @property
    def source(self) -> global___DataTransferDataSourceSink: ...
    worker_count: builtins.int
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        name: builtins.str = ...,
        destination: global___DataTransferDataSourceSink | None = ...,
        source: global___DataTransferDataSourceSink | None = ...,
        worker_count: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["destination", b"destination", "resource_info", b"resource_info", "source", b"source"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["destination", b"destination", "name", b"name", "resource_info", b"resource_info", "source", b"source", "worker_count", b"worker_count"]) -> None: ...

global___DatabaseAccountsDataTransferJobs = DatabaseAccountsDataTransferJobs

@typing_extensions.final
class DataTransferDataSourceSink(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    name: builtins.str
    def __init__(
        self,
        *,
        name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["name", b"name"]) -> None: ...

global___DataTransferDataSourceSink = DataTransferDataSourceSink

@typing_extensions.final
class DatabaseAccountsCassandraKeyspacesViewsThroughputSettings(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class TagsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    IDENTITY_FIELD_NUMBER: builtins.int
    LOCATION_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    RESOURCE_FIELD_NUMBER: builtins.int
    TAGS_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    @property
    def identity(self) -> global___ManagedServiceIdentity: ...
    location: builtins.str
    name: builtins.str
    @property
    def resource(self) -> global___ThroughputSettingsResource: ...
    @property
    def tags(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        identity: global___ManagedServiceIdentity | None = ...,
        location: builtins.str = ...,
        name: builtins.str = ...,
        resource: global___ThroughputSettingsResource | None = ...,
        tags: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["identity", b"identity", "resource", b"resource", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["identity", b"identity", "location", b"location", "name", b"name", "resource", b"resource", "resource_info", b"resource_info", "tags", b"tags"]) -> None: ...

global___DatabaseAccountsCassandraKeyspacesViewsThroughputSettings = DatabaseAccountsCassandraKeyspacesViewsThroughputSettings

@typing_extensions.final
class DatabaseAccountsCassandraKeyspacesViews(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class TagsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    IDENTITY_FIELD_NUMBER: builtins.int
    LOCATION_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    OPTIONS_FIELD_NUMBER: builtins.int
    RESOURCE_FIELD_NUMBER: builtins.int
    TAGS_FIELD_NUMBER: builtins.int
    DATABASE_ACCOUNTS_CASSANDRA_KEYSPACES_VIEWS_THROUGHPUT_SETTINGS_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    @property
    def identity(self) -> global___ManagedServiceIdentity: ...
    location: builtins.str
    name: builtins.str
    @property
    def options(self) -> global___CreateUpdateOptions: ...
    @property
    def resource(self) -> global___CassandraViewResource: ...
    @property
    def tags(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    @property
    def database_accounts_cassandra_keyspaces_views_throughput_settings(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___DatabaseAccountsCassandraKeyspacesViewsThroughputSettings]: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        identity: global___ManagedServiceIdentity | None = ...,
        location: builtins.str = ...,
        name: builtins.str = ...,
        options: global___CreateUpdateOptions | None = ...,
        resource: global___CassandraViewResource | None = ...,
        tags: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        database_accounts_cassandra_keyspaces_views_throughput_settings: collections.abc.Iterable[global___DatabaseAccountsCassandraKeyspacesViewsThroughputSettings] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["identity", b"identity", "options", b"options", "resource", b"resource", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["database_accounts_cassandra_keyspaces_views_throughput_settings", b"database_accounts_cassandra_keyspaces_views_throughput_settings", "identity", b"identity", "location", b"location", "name", b"name", "options", b"options", "resource", b"resource", "resource_info", b"resource_info", "tags", b"tags"]) -> None: ...

global___DatabaseAccountsCassandraKeyspacesViews = DatabaseAccountsCassandraKeyspacesViews

@typing_extensions.final
class CassandraViewResource(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ID_FIELD_NUMBER: builtins.int
    VIEW_DEFINITION_FIELD_NUMBER: builtins.int
    id: builtins.str
    view_definition: builtins.str
    def __init__(
        self,
        *,
        id: builtins.str = ...,
        view_definition: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["id", b"id", "view_definition", b"view_definition"]) -> None: ...

global___CassandraViewResource = CassandraViewResource

@typing_extensions.final
class DatabaseAccountsCassandraKeyspacesThroughputSettings(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class TagsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    IDENTITY_FIELD_NUMBER: builtins.int
    LOCATION_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    RESOURCE_FIELD_NUMBER: builtins.int
    TAGS_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    @property
    def identity(self) -> global___ManagedServiceIdentity: ...
    location: builtins.str
    name: builtins.str
    @property
    def resource(self) -> global___ThroughputSettingsResource: ...
    @property
    def tags(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        identity: global___ManagedServiceIdentity | None = ...,
        location: builtins.str = ...,
        name: builtins.str = ...,
        resource: global___ThroughputSettingsResource | None = ...,
        tags: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["identity", b"identity", "resource", b"resource", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["identity", b"identity", "location", b"location", "name", b"name", "resource", b"resource", "resource_info", b"resource_info", "tags", b"tags"]) -> None: ...

global___DatabaseAccountsCassandraKeyspacesThroughputSettings = DatabaseAccountsCassandraKeyspacesThroughputSettings

@typing_extensions.final
class DatabaseAccountsCassandraKeyspacesTablesThroughputSettings(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class TagsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    IDENTITY_FIELD_NUMBER: builtins.int
    LOCATION_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    RESOURCE_FIELD_NUMBER: builtins.int
    TAGS_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    @property
    def identity(self) -> global___ManagedServiceIdentity: ...
    location: builtins.str
    name: builtins.str
    @property
    def resource(self) -> global___ThroughputSettingsResource: ...
    @property
    def tags(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        identity: global___ManagedServiceIdentity | None = ...,
        location: builtins.str = ...,
        name: builtins.str = ...,
        resource: global___ThroughputSettingsResource | None = ...,
        tags: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["identity", b"identity", "resource", b"resource", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["identity", b"identity", "location", b"location", "name", b"name", "resource", b"resource", "resource_info", b"resource_info", "tags", b"tags"]) -> None: ...

global___DatabaseAccountsCassandraKeyspacesTablesThroughputSettings = DatabaseAccountsCassandraKeyspacesTablesThroughputSettings

@typing_extensions.final
class ThroughputSettingsResource(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    AUTOSCALE_SETTINGS_FIELD_NUMBER: builtins.int
    THROUGHPUT_FIELD_NUMBER: builtins.int
    @property
    def autoscale_settings(self) -> global___AutoscaleSettingsResource: ...
    throughput: builtins.int
    def __init__(
        self,
        *,
        autoscale_settings: global___AutoscaleSettingsResource | None = ...,
        throughput: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["autoscale_settings", b"autoscale_settings"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["autoscale_settings", b"autoscale_settings", "throughput", b"throughput"]) -> None: ...

global___ThroughputSettingsResource = ThroughputSettingsResource

@typing_extensions.final
class AutoscaleSettingsResource(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    AUTO_UPGRADE_POLICY_FIELD_NUMBER: builtins.int
    MAX_THROUGHPUT_FIELD_NUMBER: builtins.int
    @property
    def auto_upgrade_policy(self) -> global___AutoUpgradePolicyResource: ...
    max_throughput: builtins.int
    def __init__(
        self,
        *,
        auto_upgrade_policy: global___AutoUpgradePolicyResource | None = ...,
        max_throughput: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["auto_upgrade_policy", b"auto_upgrade_policy"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["auto_upgrade_policy", b"auto_upgrade_policy", "max_throughput", b"max_throughput"]) -> None: ...

global___AutoscaleSettingsResource = AutoscaleSettingsResource

@typing_extensions.final
class AutoUpgradePolicyResource(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    THROUGHPUT_POLICY_FIELD_NUMBER: builtins.int
    @property
    def throughput_policy(self) -> global___ThroughputPolicyResource: ...
    def __init__(
        self,
        *,
        throughput_policy: global___ThroughputPolicyResource | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["throughput_policy", b"throughput_policy"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["throughput_policy", b"throughput_policy"]) -> None: ...

global___AutoUpgradePolicyResource = AutoUpgradePolicyResource

@typing_extensions.final
class ThroughputPolicyResource(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INCREMENT_PERCENT_FIELD_NUMBER: builtins.int
    IS_ENABLED_FIELD_NUMBER: builtins.int
    increment_percent: builtins.int
    is_enabled: builtins.bool
    def __init__(
        self,
        *,
        increment_percent: builtins.int = ...,
        is_enabled: builtins.bool = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["increment_percent", b"increment_percent", "is_enabled", b"is_enabled"]) -> None: ...

global___ThroughputPolicyResource = ThroughputPolicyResource

@typing_extensions.final
class DatabaseAccountsCassandraKeyspacesTables(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class TagsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    IDENTITY_FIELD_NUMBER: builtins.int
    LOCATION_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    OPTIONS_FIELD_NUMBER: builtins.int
    RESOURCE_FIELD_NUMBER: builtins.int
    TAGS_FIELD_NUMBER: builtins.int
    DATABASE_ACCOUNTS_CASSANDRA_KEYSPACES_TABLES_THROUGHPUT_SETTINGS_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    @property
    def identity(self) -> global___ManagedServiceIdentity: ...
    location: builtins.str
    name: builtins.str
    @property
    def options(self) -> global___CreateUpdateOptions: ...
    @property
    def resource(self) -> global___CassandraTableResource: ...
    @property
    def tags(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    @property
    def database_accounts_cassandra_keyspaces_tables_throughput_settings(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___DatabaseAccountsCassandraKeyspacesTablesThroughputSettings]: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        identity: global___ManagedServiceIdentity | None = ...,
        location: builtins.str = ...,
        name: builtins.str = ...,
        options: global___CreateUpdateOptions | None = ...,
        resource: global___CassandraTableResource | None = ...,
        tags: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        database_accounts_cassandra_keyspaces_tables_throughput_settings: collections.abc.Iterable[global___DatabaseAccountsCassandraKeyspacesTablesThroughputSettings] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["identity", b"identity", "options", b"options", "resource", b"resource", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["database_accounts_cassandra_keyspaces_tables_throughput_settings", b"database_accounts_cassandra_keyspaces_tables_throughput_settings", "identity", b"identity", "location", b"location", "name", b"name", "options", b"options", "resource", b"resource", "resource_info", b"resource_info", "tags", b"tags"]) -> None: ...

global___DatabaseAccountsCassandraKeyspacesTables = DatabaseAccountsCassandraKeyspacesTables

@typing_extensions.final
class CassandraTableResource(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ANALYTICAL_STORAGE_TTL_FIELD_NUMBER: builtins.int
    DEFAULT_TTL_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    SCHEMA_FIELD_NUMBER: builtins.int
    analytical_storage_ttl: builtins.int
    default_ttl: builtins.int
    id: builtins.str
    @property
    def schema(self) -> global___CassandraSchema: ...
    def __init__(
        self,
        *,
        analytical_storage_ttl: builtins.int = ...,
        default_ttl: builtins.int = ...,
        id: builtins.str = ...,
        schema: global___CassandraSchema | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["schema", b"schema"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["analytical_storage_ttl", b"analytical_storage_ttl", "default_ttl", b"default_ttl", "id", b"id", "schema", b"schema"]) -> None: ...

global___CassandraTableResource = CassandraTableResource

@typing_extensions.final
class CassandraSchema(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CLUSTER_KEYS_FIELD_NUMBER: builtins.int
    COLUMNS_FIELD_NUMBER: builtins.int
    PARTITION_KEYS_FIELD_NUMBER: builtins.int
    @property
    def cluster_keys(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ClusterKey]: ...
    @property
    def columns(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Column]: ...
    @property
    def partition_keys(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___CassandraPartitionKey]: ...
    def __init__(
        self,
        *,
        cluster_keys: collections.abc.Iterable[global___ClusterKey] | None = ...,
        columns: collections.abc.Iterable[global___Column] | None = ...,
        partition_keys: collections.abc.Iterable[global___CassandraPartitionKey] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["cluster_keys", b"cluster_keys", "columns", b"columns", "partition_keys", b"partition_keys"]) -> None: ...

global___CassandraSchema = CassandraSchema

@typing_extensions.final
class CassandraPartitionKey(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    name: builtins.str
    def __init__(
        self,
        *,
        name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["name", b"name"]) -> None: ...

global___CassandraPartitionKey = CassandraPartitionKey

@typing_extensions.final
class Column(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    name: builtins.str
    type: builtins.str
    def __init__(
        self,
        *,
        name: builtins.str = ...,
        type: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["name", b"name", "type", b"type"]) -> None: ...

global___Column = Column

@typing_extensions.final
class ClusterKey(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    ORDER_BY_FIELD_NUMBER: builtins.int
    name: builtins.str
    order_by: builtins.str
    def __init__(
        self,
        *,
        name: builtins.str = ...,
        order_by: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["name", b"name", "order_by", b"order_by"]) -> None: ...

global___ClusterKey = ClusterKey

@typing_extensions.final
class DatabaseAccountsCassandraKeyspaces(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class TagsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    IDENTITY_FIELD_NUMBER: builtins.int
    LOCATION_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    OPTIONS_FIELD_NUMBER: builtins.int
    RESOURCE_FIELD_NUMBER: builtins.int
    TAGS_FIELD_NUMBER: builtins.int
    DATABASE_ACCOUNTS_CASSANDRA_KEYSPACES_THROUGHPUT_SETTINGS_FIELD_NUMBER: builtins.int
    DATABASE_ACCOUNTS_CASSANDRA_KEYSPACES_VIEWS_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    @property
    def identity(self) -> global___ManagedServiceIdentity: ...
    location: builtins.str
    name: builtins.str
    @property
    def options(self) -> global___CreateUpdateOptions: ...
    @property
    def resource(self) -> global___CassandraKeyspaceResource: ...
    @property
    def tags(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    @property
    def database_accounts_cassandra_keyspaces_throughput_settings(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___DatabaseAccountsCassandraKeyspacesThroughputSettings]: ...
    @property
    def database_accounts_cassandra_keyspaces_views(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___DatabaseAccountsCassandraKeyspacesViews]: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        identity: global___ManagedServiceIdentity | None = ...,
        location: builtins.str = ...,
        name: builtins.str = ...,
        options: global___CreateUpdateOptions | None = ...,
        resource: global___CassandraKeyspaceResource | None = ...,
        tags: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        database_accounts_cassandra_keyspaces_throughput_settings: collections.abc.Iterable[global___DatabaseAccountsCassandraKeyspacesThroughputSettings] | None = ...,
        database_accounts_cassandra_keyspaces_views: collections.abc.Iterable[global___DatabaseAccountsCassandraKeyspacesViews] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["identity", b"identity", "options", b"options", "resource", b"resource", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["database_accounts_cassandra_keyspaces_throughput_settings", b"database_accounts_cassandra_keyspaces_throughput_settings", "database_accounts_cassandra_keyspaces_views", b"database_accounts_cassandra_keyspaces_views", "identity", b"identity", "location", b"location", "name", b"name", "options", b"options", "resource", b"resource", "resource_info", b"resource_info", "tags", b"tags"]) -> None: ...

global___DatabaseAccountsCassandraKeyspaces = DatabaseAccountsCassandraKeyspaces

@typing_extensions.final
class CassandraKeyspaceResource(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ID_FIELD_NUMBER: builtins.int
    id: builtins.str
    def __init__(
        self,
        *,
        id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["id", b"id"]) -> None: ...

global___CassandraKeyspaceResource = CassandraKeyspaceResource

@typing_extensions.final
class CreateUpdateOptions(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    AUTOSCALE_SETTINGS_FIELD_NUMBER: builtins.int
    THROUGHPUT_FIELD_NUMBER: builtins.int
    @property
    def autoscale_settings(self) -> global___AutoscaleSettings: ...
    throughput: builtins.int
    def __init__(
        self,
        *,
        autoscale_settings: global___AutoscaleSettings | None = ...,
        throughput: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["autoscale_settings", b"autoscale_settings"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["autoscale_settings", b"autoscale_settings", "throughput", b"throughput"]) -> None: ...

global___CreateUpdateOptions = CreateUpdateOptions

@typing_extensions.final
class AutoscaleSettings(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MAX_THROUGHPUT_FIELD_NUMBER: builtins.int
    max_throughput: builtins.int
    def __init__(
        self,
        *,
        max_throughput: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["max_throughput", b"max_throughput"]) -> None: ...

global___AutoscaleSettings = AutoscaleSettings

@typing_extensions.final
class DatabaseAccounts(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class TagsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    IDENTITY_FIELD_NUMBER: builtins.int
    KIND_FIELD_NUMBER: builtins.int
    LOCATION_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    ANALYTICAL_STORAGE_CONFIGURATION_FIELD_NUMBER: builtins.int
    API_PROPERTIES_FIELD_NUMBER: builtins.int
    BACKUP_POLICY_FIELD_NUMBER: builtins.int
    CAPABILITIES_FIELD_NUMBER: builtins.int
    CAPACITY_FIELD_NUMBER: builtins.int
    CONNECTOR_OFFER_FIELD_NUMBER: builtins.int
    CONSISTENCY_POLICY_FIELD_NUMBER: builtins.int
    CORS_FIELD_NUMBER: builtins.int
    CREATE_MODE_FIELD_NUMBER: builtins.int
    DATABASE_ACCOUNT_OFFER_TYPE_FIELD_NUMBER: builtins.int
    DEFAULT_IDENTITY_FIELD_NUMBER: builtins.int
    DIAGNOSTIC_LOG_SETTINGS_FIELD_NUMBER: builtins.int
    DISABLE_KEY_BASED_METADATA_WRITE_ACCESS_FIELD_NUMBER: builtins.int
    DISABLE_LOCAL_AUTH_FIELD_NUMBER: builtins.int
    ENABLE_ANALYTICAL_STORAGE_FIELD_NUMBER: builtins.int
    ENABLE_AUTOMATIC_FAILOVER_FIELD_NUMBER: builtins.int
    ENABLE_CASSANDRA_CONNECTOR_FIELD_NUMBER: builtins.int
    ENABLE_FREE_TIER_FIELD_NUMBER: builtins.int
    ENABLE_MATERIALIZED_VIEWS_FIELD_NUMBER: builtins.int
    ENABLE_MULTIPLE_WRITE_LOCATIONS_FIELD_NUMBER: builtins.int
    IP_RULES_FIELD_NUMBER: builtins.int
    IS_VIRTUAL_NETWORK_FILTER_ENABLED_FIELD_NUMBER: builtins.int
    KEY_VAULT_KEY_URI_FIELD_NUMBER: builtins.int
    LOCATIONS_FIELD_NUMBER: builtins.int
    NETWORK_ACL_BYPASS_FIELD_NUMBER: builtins.int
    NETWORK_ACL_BYPASS_RESOURCE_IDS_FIELD_NUMBER: builtins.int
    PUBLIC_NETWORK_ACCESS_FIELD_NUMBER: builtins.int
    RESTORE_PARAMETERS_FIELD_NUMBER: builtins.int
    VIRTUAL_NETWORK_RULES_FIELD_NUMBER: builtins.int
    TAGS_FIELD_NUMBER: builtins.int
    DATABASE_ACCOUNTS_GRAPHS_FIELD_NUMBER: builtins.int
    DATABASE_ACCOUNTS_SQL_ROLE_DEFINITIONS_FIELD_NUMBER: builtins.int
    DATABASE_ACCOUNTS_SQL_ROLE_ASSIGNMENTS_FIELD_NUMBER: builtins.int
    DATABASE_ACCOUNTS_MONGODB_DATABASES_FIELD_NUMBER: builtins.int
    DATABASE_ACCOUNTS_MONGODB_ROLE_DEFINITIONS_FIELD_NUMBER: builtins.int
    DATABASE_ACCOUNTS_MONGODB_USER_DEFINITIONS_FIELD_NUMBER: builtins.int
    DATABASE_ACCOUNTS_TABLES_FIELD_NUMBER: builtins.int
    DATABASE_ACCOUNTS_GREMLIN_DATABASES_FIELD_NUMBER: builtins.int
    DATABASE_ACCOUNTS_DATA_TRANSFER_JOBS_FIELD_NUMBER: builtins.int
    DATABASE_ACCOUNTS_NOTEBOOK_WORKSPACES_FIELD_NUMBER: builtins.int
    DATABASE_ACCOUNTS_PRIVATE_ENDPOINT_CONNECTIONS_FIELD_NUMBER: builtins.int
    DATABASE_ACCOUNTS_SERVICES_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    @property
    def identity(self) -> global___ManagedServiceIdentity: ...
    kind: builtins.str
    location: builtins.str
    name: builtins.str
    @property
    def analytical_storage_configuration(self) -> global___AnalyticalStorageConfiguration: ...
    @property
    def api_properties(self) -> global___ApiProperties: ...
    @property
    def backup_policy(self) -> global___BackupPolicy: ...
    @property
    def capabilities(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Capability]: ...
    @property
    def capacity(self) -> global___Capacity: ...
    connector_offer: builtins.str
    @property
    def consistency_policy(self) -> global___ConsistencyPolicy: ...
    @property
    def cors(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___CorsPolicy]: ...
    create_mode: builtins.str
    database_account_offer_type: builtins.str
    default_identity: builtins.str
    @property
    def diagnostic_log_settings(self) -> global___DiagnosticLogSettings: ...
    disable_key_based_metadata_write_access: builtins.bool
    disable_local_auth: builtins.bool
    enable_analytical_storage: builtins.bool
    enable_automatic_failover: builtins.bool
    enable_cassandra_connector: builtins.bool
    enable_free_tier: builtins.bool
    enable_materialized_views: builtins.bool
    enable_multiple_write_locations: builtins.bool
    @property
    def ip_rules(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___IpAddressOrRange]: ...
    is_virtual_network_filter_enabled: builtins.bool
    key_vault_key_uri: builtins.str
    @property
    def locations(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Location]: ...
    network_acl_bypass: builtins.str
    @property
    def network_acl_bypass_resource_ids(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    public_network_access: builtins.str
    @property
    def restore_parameters(self) -> global___RestoreParameters: ...
    @property
    def virtual_network_rules(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___VirtualNetworkRule]: ...
    @property
    def tags(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    @property
    def database_accounts_graphs(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___DatabaseAccountsGraphs]: ...
    @property
    def database_accounts_sql_role_definitions(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___DatabaseAccountsSqlRoleDefinitions]: ...
    @property
    def database_accounts_sql_role_assignments(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___DatabaseAccountsSqlRoleAssignments]: ...
    @property
    def database_accounts_mongodb_databases(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___DatabaseAccountsMongodbDatabases]: ...
    @property
    def database_accounts_mongodb_role_definitions(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___DatabaseAccountsMongodbRoleDefinitions]: ...
    @property
    def database_accounts_mongodb_user_definitions(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___DatabaseAccountsMongodbUserDefinitions]: ...
    @property
    def database_accounts_tables(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___DatabaseAccountsTables]: ...
    @property
    def database_accounts_gremlin_databases(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___DatabaseAccountsGremlinDatabases]: ...
    @property
    def database_accounts_data_transfer_jobs(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___DatabaseAccountsDataTransferJobs]: ...
    @property
    def database_accounts_notebook_workspaces(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___DatabaseAccountsNotebookWorkspaces]: ...
    @property
    def database_accounts_private_endpoint_connections(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___DatabaseAccountsPrivateEndpointConnections]: ...
    @property
    def database_accounts_services(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___DatabaseAccountsServices]: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        identity: global___ManagedServiceIdentity | None = ...,
        kind: builtins.str = ...,
        location: builtins.str = ...,
        name: builtins.str = ...,
        analytical_storage_configuration: global___AnalyticalStorageConfiguration | None = ...,
        api_properties: global___ApiProperties | None = ...,
        backup_policy: global___BackupPolicy | None = ...,
        capabilities: collections.abc.Iterable[global___Capability] | None = ...,
        capacity: global___Capacity | None = ...,
        connector_offer: builtins.str = ...,
        consistency_policy: global___ConsistencyPolicy | None = ...,
        cors: collections.abc.Iterable[global___CorsPolicy] | None = ...,
        create_mode: builtins.str = ...,
        database_account_offer_type: builtins.str = ...,
        default_identity: builtins.str = ...,
        diagnostic_log_settings: global___DiagnosticLogSettings | None = ...,
        disable_key_based_metadata_write_access: builtins.bool = ...,
        disable_local_auth: builtins.bool = ...,
        enable_analytical_storage: builtins.bool = ...,
        enable_automatic_failover: builtins.bool = ...,
        enable_cassandra_connector: builtins.bool = ...,
        enable_free_tier: builtins.bool = ...,
        enable_materialized_views: builtins.bool = ...,
        enable_multiple_write_locations: builtins.bool = ...,
        ip_rules: collections.abc.Iterable[global___IpAddressOrRange] | None = ...,
        is_virtual_network_filter_enabled: builtins.bool = ...,
        key_vault_key_uri: builtins.str = ...,
        locations: collections.abc.Iterable[global___Location] | None = ...,
        network_acl_bypass: builtins.str = ...,
        network_acl_bypass_resource_ids: collections.abc.Iterable[builtins.str] | None = ...,
        public_network_access: builtins.str = ...,
        restore_parameters: global___RestoreParameters | None = ...,
        virtual_network_rules: collections.abc.Iterable[global___VirtualNetworkRule] | None = ...,
        tags: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        database_accounts_graphs: collections.abc.Iterable[global___DatabaseAccountsGraphs] | None = ...,
        database_accounts_sql_role_definitions: collections.abc.Iterable[global___DatabaseAccountsSqlRoleDefinitions] | None = ...,
        database_accounts_sql_role_assignments: collections.abc.Iterable[global___DatabaseAccountsSqlRoleAssignments] | None = ...,
        database_accounts_mongodb_databases: collections.abc.Iterable[global___DatabaseAccountsMongodbDatabases] | None = ...,
        database_accounts_mongodb_role_definitions: collections.abc.Iterable[global___DatabaseAccountsMongodbRoleDefinitions] | None = ...,
        database_accounts_mongodb_user_definitions: collections.abc.Iterable[global___DatabaseAccountsMongodbUserDefinitions] | None = ...,
        database_accounts_tables: collections.abc.Iterable[global___DatabaseAccountsTables] | None = ...,
        database_accounts_gremlin_databases: collections.abc.Iterable[global___DatabaseAccountsGremlinDatabases] | None = ...,
        database_accounts_data_transfer_jobs: collections.abc.Iterable[global___DatabaseAccountsDataTransferJobs] | None = ...,
        database_accounts_notebook_workspaces: collections.abc.Iterable[global___DatabaseAccountsNotebookWorkspaces] | None = ...,
        database_accounts_private_endpoint_connections: collections.abc.Iterable[global___DatabaseAccountsPrivateEndpointConnections] | None = ...,
        database_accounts_services: collections.abc.Iterable[global___DatabaseAccountsServices] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["analytical_storage_configuration", b"analytical_storage_configuration", "api_properties", b"api_properties", "backup_policy", b"backup_policy", "capacity", b"capacity", "consistency_policy", b"consistency_policy", "diagnostic_log_settings", b"diagnostic_log_settings", "identity", b"identity", "resource_info", b"resource_info", "restore_parameters", b"restore_parameters"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["analytical_storage_configuration", b"analytical_storage_configuration", "api_properties", b"api_properties", "backup_policy", b"backup_policy", "capabilities", b"capabilities", "capacity", b"capacity", "connector_offer", b"connector_offer", "consistency_policy", b"consistency_policy", "cors", b"cors", "create_mode", b"create_mode", "database_account_offer_type", b"database_account_offer_type", "database_accounts_data_transfer_jobs", b"database_accounts_data_transfer_jobs", "database_accounts_graphs", b"database_accounts_graphs", "database_accounts_gremlin_databases", b"database_accounts_gremlin_databases", "database_accounts_mongodb_databases", b"database_accounts_mongodb_databases", "database_accounts_mongodb_role_definitions", b"database_accounts_mongodb_role_definitions", "database_accounts_mongodb_user_definitions", b"database_accounts_mongodb_user_definitions", "database_accounts_notebook_workspaces", b"database_accounts_notebook_workspaces", "database_accounts_private_endpoint_connections", b"database_accounts_private_endpoint_connections", "database_accounts_services", b"database_accounts_services", "database_accounts_sql_role_assignments", b"database_accounts_sql_role_assignments", "database_accounts_sql_role_definitions", b"database_accounts_sql_role_definitions", "database_accounts_tables", b"database_accounts_tables", "default_identity", b"default_identity", "diagnostic_log_settings", b"diagnostic_log_settings", "disable_key_based_metadata_write_access", b"disable_key_based_metadata_write_access", "disable_local_auth", b"disable_local_auth", "enable_analytical_storage", b"enable_analytical_storage", "enable_automatic_failover", b"enable_automatic_failover", "enable_cassandra_connector", b"enable_cassandra_connector", "enable_free_tier", b"enable_free_tier", "enable_materialized_views", b"enable_materialized_views", "enable_multiple_write_locations", b"enable_multiple_write_locations", "identity", b"identity", "ip_rules", b"ip_rules", "is_virtual_network_filter_enabled", b"is_virtual_network_filter_enabled", "key_vault_key_uri", b"key_vault_key_uri", "kind", b"kind", "location", b"location", "locations", b"locations", "name", b"name", "network_acl_bypass", b"network_acl_bypass", "network_acl_bypass_resource_ids", b"network_acl_bypass_resource_ids", "public_network_access", b"public_network_access", "resource_info", b"resource_info", "restore_parameters", b"restore_parameters", "tags", b"tags", "virtual_network_rules", b"virtual_network_rules"]) -> None: ...

global___DatabaseAccounts = DatabaseAccounts

@typing_extensions.final
class VirtualNetworkRule(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ID_FIELD_NUMBER: builtins.int
    IGNORE_MISSING_V_NET_SERVICE_ENDPOINT_FIELD_NUMBER: builtins.int
    id: builtins.str
    ignore_missing_v_net_service_endpoint: builtins.bool
    def __init__(
        self,
        *,
        id: builtins.str = ...,
        ignore_missing_v_net_service_endpoint: builtins.bool = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["id", b"id", "ignore_missing_v_net_service_endpoint", b"ignore_missing_v_net_service_endpoint"]) -> None: ...

global___VirtualNetworkRule = VirtualNetworkRule

@typing_extensions.final
class RestoreParameters(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DATABASES_TO_RESTORE_FIELD_NUMBER: builtins.int
    GREMLIN_DATABASES_TO_RESTORE_FIELD_NUMBER: builtins.int
    RESTORE_MODE_FIELD_NUMBER: builtins.int
    RESTORE_SOURCE_FIELD_NUMBER: builtins.int
    RESTORE_TIMESTAMP_IN_UTC_FIELD_NUMBER: builtins.int
    TABLES_TO_RESTORE_FIELD_NUMBER: builtins.int
    @property
    def databases_to_restore(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___DatabaseRestoreResource]: ...
    @property
    def gremlin_databases_to_restore(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___GremlinDatabaseRestoreResource]: ...
    restore_mode: builtins.str
    restore_source: builtins.str
    restore_timestamp_in_utc: builtins.str
    @property
    def tables_to_restore(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    def __init__(
        self,
        *,
        databases_to_restore: collections.abc.Iterable[global___DatabaseRestoreResource] | None = ...,
        gremlin_databases_to_restore: collections.abc.Iterable[global___GremlinDatabaseRestoreResource] | None = ...,
        restore_mode: builtins.str = ...,
        restore_source: builtins.str = ...,
        restore_timestamp_in_utc: builtins.str = ...,
        tables_to_restore: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["databases_to_restore", b"databases_to_restore", "gremlin_databases_to_restore", b"gremlin_databases_to_restore", "restore_mode", b"restore_mode", "restore_source", b"restore_source", "restore_timestamp_in_utc", b"restore_timestamp_in_utc", "tables_to_restore", b"tables_to_restore"]) -> None: ...

global___RestoreParameters = RestoreParameters

@typing_extensions.final
class GremlinDatabaseRestoreResource(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DATABASE_NAME_FIELD_NUMBER: builtins.int
    GRAPH_NAMES_FIELD_NUMBER: builtins.int
    database_name: builtins.str
    @property
    def graph_names(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    def __init__(
        self,
        *,
        database_name: builtins.str = ...,
        graph_names: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["database_name", b"database_name", "graph_names", b"graph_names"]) -> None: ...

global___GremlinDatabaseRestoreResource = GremlinDatabaseRestoreResource

@typing_extensions.final
class DatabaseRestoreResource(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    COLLECTION_NAMES_FIELD_NUMBER: builtins.int
    DATABASE_NAME_FIELD_NUMBER: builtins.int
    @property
    def collection_names(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    database_name: builtins.str
    def __init__(
        self,
        *,
        collection_names: collections.abc.Iterable[builtins.str] | None = ...,
        database_name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["collection_names", b"collection_names", "database_name", b"database_name"]) -> None: ...

global___DatabaseRestoreResource = DatabaseRestoreResource

@typing_extensions.final
class Location(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FAILOVER_PRIORITY_FIELD_NUMBER: builtins.int
    IS_ZONE_REDUNDANT_FIELD_NUMBER: builtins.int
    LOCATION_NAME_FIELD_NUMBER: builtins.int
    PROVISIONING_STATE_FIELD_NUMBER: builtins.int
    failover_priority: builtins.int
    is_zone_redundant: builtins.bool
    location_name: builtins.str
    provisioning_state: builtins.str
    def __init__(
        self,
        *,
        failover_priority: builtins.int = ...,
        is_zone_redundant: builtins.bool = ...,
        location_name: builtins.str = ...,
        provisioning_state: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["failover_priority", b"failover_priority", "is_zone_redundant", b"is_zone_redundant", "location_name", b"location_name", "provisioning_state", b"provisioning_state"]) -> None: ...

global___Location = Location

@typing_extensions.final
class IpAddressOrRange(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    IP_ADDRESS_OR_RANGE_FIELD_NUMBER: builtins.int
    ip_address_or_range: builtins.str
    def __init__(
        self,
        *,
        ip_address_or_range: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["ip_address_or_range", b"ip_address_or_range"]) -> None: ...

global___IpAddressOrRange = IpAddressOrRange

@typing_extensions.final
class DiagnosticLogSettings(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ENABLE_FULL_TEXT_QUERY_FIELD_NUMBER: builtins.int
    enable_full_text_query: builtins.str
    def __init__(
        self,
        *,
        enable_full_text_query: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["enable_full_text_query", b"enable_full_text_query"]) -> None: ...

global___DiagnosticLogSettings = DiagnosticLogSettings

@typing_extensions.final
class CorsPolicy(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ALLOWED_HEADERS_FIELD_NUMBER: builtins.int
    ALLOWED_METHODS_FIELD_NUMBER: builtins.int
    ALLOWED_ORIGINS_FIELD_NUMBER: builtins.int
    EXPOSED_HEADERS_FIELD_NUMBER: builtins.int
    MAX_AGE_IN_SECONDS_FIELD_NUMBER: builtins.int
    allowed_headers: builtins.str
    allowed_methods: builtins.str
    allowed_origins: builtins.str
    exposed_headers: builtins.str
    max_age_in_seconds: builtins.int
    def __init__(
        self,
        *,
        allowed_headers: builtins.str = ...,
        allowed_methods: builtins.str = ...,
        allowed_origins: builtins.str = ...,
        exposed_headers: builtins.str = ...,
        max_age_in_seconds: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["allowed_headers", b"allowed_headers", "allowed_methods", b"allowed_methods", "allowed_origins", b"allowed_origins", "exposed_headers", b"exposed_headers", "max_age_in_seconds", b"max_age_in_seconds"]) -> None: ...

global___CorsPolicy = CorsPolicy

@typing_extensions.final
class ConsistencyPolicy(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DEFAULT_CONSISTENCY_LEVEL_FIELD_NUMBER: builtins.int
    MAX_INTERVAL_IN_SECONDS_FIELD_NUMBER: builtins.int
    MAX_STALENESS_PREFIX_FIELD_NUMBER: builtins.int
    default_consistency_level: builtins.str
    max_interval_in_seconds: builtins.int
    max_staleness_prefix: builtins.int
    def __init__(
        self,
        *,
        default_consistency_level: builtins.str = ...,
        max_interval_in_seconds: builtins.int = ...,
        max_staleness_prefix: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["default_consistency_level", b"default_consistency_level", "max_interval_in_seconds", b"max_interval_in_seconds", "max_staleness_prefix", b"max_staleness_prefix"]) -> None: ...

global___ConsistencyPolicy = ConsistencyPolicy

@typing_extensions.final
class Capacity(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TOTAL_THROUGHPUT_LIMIT_FIELD_NUMBER: builtins.int
    total_throughput_limit: builtins.int
    def __init__(
        self,
        *,
        total_throughput_limit: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["total_throughput_limit", b"total_throughput_limit"]) -> None: ...

global___Capacity = Capacity

@typing_extensions.final
class Capability(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    name: builtins.str
    def __init__(
        self,
        *,
        name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["name", b"name"]) -> None: ...

global___Capability = Capability

@typing_extensions.final
class BackupPolicy(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MIGRATION_STATE_FIELD_NUMBER: builtins.int
    @property
    def migration_state(self) -> global___BackupPolicyMigrationState: ...
    def __init__(
        self,
        *,
        migration_state: global___BackupPolicyMigrationState | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["migration_state", b"migration_state"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["migration_state", b"migration_state"]) -> None: ...

global___BackupPolicy = BackupPolicy

@typing_extensions.final
class BackupPolicyMigrationState(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    START_TIME_FIELD_NUMBER: builtins.int
    STATUS_FIELD_NUMBER: builtins.int
    TARGET_TYPE_FIELD_NUMBER: builtins.int
    start_time: builtins.str
    status: builtins.str
    target_type: builtins.str
    def __init__(
        self,
        *,
        start_time: builtins.str = ...,
        status: builtins.str = ...,
        target_type: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["start_time", b"start_time", "status", b"status", "target_type", b"target_type"]) -> None: ...

global___BackupPolicyMigrationState = BackupPolicyMigrationState

@typing_extensions.final
class ApiProperties(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SERVER_VERSION_FIELD_NUMBER: builtins.int
    server_version: builtins.str
    def __init__(
        self,
        *,
        server_version: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["server_version", b"server_version"]) -> None: ...

global___ApiProperties = ApiProperties

@typing_extensions.final
class AnalyticalStorageConfiguration(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SCHEMA_TYPE_FIELD_NUMBER: builtins.int
    schema_type: builtins.str
    def __init__(
        self,
        *,
        schema_type: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["schema_type", b"schema_type"]) -> None: ...

global___AnalyticalStorageConfiguration = AnalyticalStorageConfiguration

@typing_extensions.final
class ManagedServiceIdentity(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class UserAssignedIdentitiesEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    TYPE_FIELD_NUMBER: builtins.int
    USER_ASSIGNED_IDENTITIES_FIELD_NUMBER: builtins.int
    type: builtins.str
    @property
    def user_assigned_identities(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    def __init__(
        self,
        *,
        type: builtins.str = ...,
        user_assigned_identities: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["type", b"type", "user_assigned_identities", b"user_assigned_identities"]) -> None: ...

global___ManagedServiceIdentity = ManagedServiceIdentity

@typing_extensions.final
class CassandraClustersDataCenters(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    AUTHENTICATION_METHOD_LDAP_PROPERTIES_FIELD_NUMBER: builtins.int
    AVAILABILITY_ZONE_FIELD_NUMBER: builtins.int
    BACKUP_STORAGE_CUSTOMER_KEY_URI_FIELD_NUMBER: builtins.int
    BASE64_ENCODED_CASSANDRA_YAML_FRAGMENT_FIELD_NUMBER: builtins.int
    DATA_CENTER_LOCATION_FIELD_NUMBER: builtins.int
    DELEGATED_SUBNET_ID_FIELD_NUMBER: builtins.int
    DISK_CAPACITY_FIELD_NUMBER: builtins.int
    DISK_SKU_FIELD_NUMBER: builtins.int
    MANAGED_DISK_CUSTOMER_KEY_URI_FIELD_NUMBER: builtins.int
    NODE_COUNT_FIELD_NUMBER: builtins.int
    PROVISIONING_STATE_FIELD_NUMBER: builtins.int
    SKU_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    name: builtins.str
    @property
    def authentication_method_ldap_properties(self) -> global___AuthenticationMethodLdapProperties: ...
    availability_zone: builtins.bool
    backup_storage_customer_key_uri: builtins.str
    base64_encoded_cassandra_yaml_fragment: builtins.str
    data_center_location: builtins.str
    delegated_subnet_id: builtins.str
    disk_capacity: builtins.int
    disk_sku: builtins.str
    managed_disk_customer_key_uri: builtins.str
    node_count: builtins.int
    provisioning_state: builtins.str
    sku: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        name: builtins.str = ...,
        authentication_method_ldap_properties: global___AuthenticationMethodLdapProperties | None = ...,
        availability_zone: builtins.bool = ...,
        backup_storage_customer_key_uri: builtins.str = ...,
        base64_encoded_cassandra_yaml_fragment: builtins.str = ...,
        data_center_location: builtins.str = ...,
        delegated_subnet_id: builtins.str = ...,
        disk_capacity: builtins.int = ...,
        disk_sku: builtins.str = ...,
        managed_disk_customer_key_uri: builtins.str = ...,
        node_count: builtins.int = ...,
        provisioning_state: builtins.str = ...,
        sku: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["authentication_method_ldap_properties", b"authentication_method_ldap_properties", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["authentication_method_ldap_properties", b"authentication_method_ldap_properties", "availability_zone", b"availability_zone", "backup_storage_customer_key_uri", b"backup_storage_customer_key_uri", "base64_encoded_cassandra_yaml_fragment", b"base64_encoded_cassandra_yaml_fragment", "data_center_location", b"data_center_location", "delegated_subnet_id", b"delegated_subnet_id", "disk_capacity", b"disk_capacity", "disk_sku", b"disk_sku", "managed_disk_customer_key_uri", b"managed_disk_customer_key_uri", "name", b"name", "node_count", b"node_count", "provisioning_state", b"provisioning_state", "resource_info", b"resource_info", "sku", b"sku"]) -> None: ...

global___CassandraClustersDataCenters = CassandraClustersDataCenters

@typing_extensions.final
class AuthenticationMethodLdapProperties(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SEARCH_BASE_DISTINGUISHED_NAME_FIELD_NUMBER: builtins.int
    SEARCH_FILTER_TEMPLATE_FIELD_NUMBER: builtins.int
    SERVER_CERTIFICATES_FIELD_NUMBER: builtins.int
    SERVER_HOSTNAME_FIELD_NUMBER: builtins.int
    SERVER_PORT_FIELD_NUMBER: builtins.int
    SERVICE_USER_DISTINGUISHED_NAME_FIELD_NUMBER: builtins.int
    SERVICE_USER_PASSWORD_FIELD_NUMBER: builtins.int
    search_base_distinguished_name: builtins.str
    search_filter_template: builtins.str
    @property
    def server_certificates(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Certificate]: ...
    server_hostname: builtins.str
    server_port: builtins.int
    service_user_distinguished_name: builtins.str
    service_user_password: builtins.str
    def __init__(
        self,
        *,
        search_base_distinguished_name: builtins.str = ...,
        search_filter_template: builtins.str = ...,
        server_certificates: collections.abc.Iterable[global___Certificate] | None = ...,
        server_hostname: builtins.str = ...,
        server_port: builtins.int = ...,
        service_user_distinguished_name: builtins.str = ...,
        service_user_password: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["search_base_distinguished_name", b"search_base_distinguished_name", "search_filter_template", b"search_filter_template", "server_certificates", b"server_certificates", "server_hostname", b"server_hostname", "server_port", b"server_port", "service_user_distinguished_name", b"service_user_distinguished_name", "service_user_password", b"service_user_password"]) -> None: ...

global___AuthenticationMethodLdapProperties = AuthenticationMethodLdapProperties

@typing_extensions.final
class CassandraClusters(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class TagsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    IDENTITY_FIELD_NUMBER: builtins.int
    LOCATION_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    AUTHENTICATION_METHOD_FIELD_NUMBER: builtins.int
    CASSANDRA_AUDIT_LOGGING_ENABLED_FIELD_NUMBER: builtins.int
    CASSANDRA_VERSION_FIELD_NUMBER: builtins.int
    CLIENT_CERTIFICATES_FIELD_NUMBER: builtins.int
    CLUSTER_NAME_OVERRIDE_FIELD_NUMBER: builtins.int
    DEALLOCATED_FIELD_NUMBER: builtins.int
    DELEGATED_MANAGEMENT_SUBNET_ID_FIELD_NUMBER: builtins.int
    EXTERNAL_GOSSIP_CERTIFICATES_FIELD_NUMBER: builtins.int
    EXTERNAL_SEED_NODES_FIELD_NUMBER: builtins.int
    HOURS_BETWEEN_BACKUPS_FIELD_NUMBER: builtins.int
    INITIAL_CASSANDRA_ADMIN_PASSWORD_FIELD_NUMBER: builtins.int
    PROMETHEUS_ENDPOINT_FIELD_NUMBER: builtins.int
    PROVISIONING_STATE_FIELD_NUMBER: builtins.int
    REPAIR_ENABLED_FIELD_NUMBER: builtins.int
    RESTORE_FROM_BACKUP_ID_FIELD_NUMBER: builtins.int
    TAGS_FIELD_NUMBER: builtins.int
    CASSANDRA_CLUSTERS_DATA_CENTERS_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    @property
    def identity(self) -> global___ManagedCassandraManagedServiceIdentity: ...
    location: builtins.str
    name: builtins.str
    authentication_method: builtins.str
    cassandra_audit_logging_enabled: builtins.bool
    cassandra_version: builtins.str
    @property
    def client_certificates(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Certificate]: ...
    cluster_name_override: builtins.str
    deallocated: builtins.bool
    delegated_management_subnet_id: builtins.str
    @property
    def external_gossip_certificates(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Certificate]: ...
    @property
    def external_seed_nodes(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___SeedNode]: ...
    hours_between_backups: builtins.int
    initial_cassandra_admin_password: builtins.str
    @property
    def prometheus_endpoint(self) -> global___SeedNode: ...
    provisioning_state: builtins.str
    repair_enabled: builtins.bool
    restore_from_backup_id: builtins.str
    @property
    def tags(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    @property
    def cassandra_clusters_data_centers(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___CassandraClustersDataCenters]: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        identity: global___ManagedCassandraManagedServiceIdentity | None = ...,
        location: builtins.str = ...,
        name: builtins.str = ...,
        authentication_method: builtins.str = ...,
        cassandra_audit_logging_enabled: builtins.bool = ...,
        cassandra_version: builtins.str = ...,
        client_certificates: collections.abc.Iterable[global___Certificate] | None = ...,
        cluster_name_override: builtins.str = ...,
        deallocated: builtins.bool = ...,
        delegated_management_subnet_id: builtins.str = ...,
        external_gossip_certificates: collections.abc.Iterable[global___Certificate] | None = ...,
        external_seed_nodes: collections.abc.Iterable[global___SeedNode] | None = ...,
        hours_between_backups: builtins.int = ...,
        initial_cassandra_admin_password: builtins.str = ...,
        prometheus_endpoint: global___SeedNode | None = ...,
        provisioning_state: builtins.str = ...,
        repair_enabled: builtins.bool = ...,
        restore_from_backup_id: builtins.str = ...,
        tags: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        cassandra_clusters_data_centers: collections.abc.Iterable[global___CassandraClustersDataCenters] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["identity", b"identity", "prometheus_endpoint", b"prometheus_endpoint", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["authentication_method", b"authentication_method", "cassandra_audit_logging_enabled", b"cassandra_audit_logging_enabled", "cassandra_clusters_data_centers", b"cassandra_clusters_data_centers", "cassandra_version", b"cassandra_version", "client_certificates", b"client_certificates", "cluster_name_override", b"cluster_name_override", "deallocated", b"deallocated", "delegated_management_subnet_id", b"delegated_management_subnet_id", "external_gossip_certificates", b"external_gossip_certificates", "external_seed_nodes", b"external_seed_nodes", "hours_between_backups", b"hours_between_backups", "identity", b"identity", "initial_cassandra_admin_password", b"initial_cassandra_admin_password", "location", b"location", "name", b"name", "prometheus_endpoint", b"prometheus_endpoint", "provisioning_state", b"provisioning_state", "repair_enabled", b"repair_enabled", "resource_info", b"resource_info", "restore_from_backup_id", b"restore_from_backup_id", "tags", b"tags"]) -> None: ...

global___CassandraClusters = CassandraClusters

@typing_extensions.final
class SeedNode(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    IP_ADDRESS_FIELD_NUMBER: builtins.int
    ip_address: builtins.str
    def __init__(
        self,
        *,
        ip_address: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["ip_address", b"ip_address"]) -> None: ...

global___SeedNode = SeedNode

@typing_extensions.final
class Certificate(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PEM_FIELD_NUMBER: builtins.int
    pem: builtins.str
    def __init__(
        self,
        *,
        pem: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["pem", b"pem"]) -> None: ...

global___Certificate = Certificate

@typing_extensions.final
class ManagedCassandraManagedServiceIdentity(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TYPE_FIELD_NUMBER: builtins.int
    type: builtins.str
    def __init__(
        self,
        *,
        type: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["type", b"type"]) -> None: ...

global___ManagedCassandraManagedServiceIdentity = ManagedCassandraManagedServiceIdentity
